@@ -211,7 +211,7 @@ Clazz.defineMethod(c$, "bytesToFixedPt",
 function(b, byteLen){
 if (b == null) return null;
 var n = Clazz.doubleToInt(b.length / byteLen);
-var a =  Clazz.newFloatArray (n, 0);
+var a =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/n, 0);
 try {
 switch (byteLen) {
 case 4:
@@ -237,7 +237,7 @@ c$.bytesToInt = Clazz.defineMethod(c$, "bytesToInt",
 function(b, byteLen, rowCount, unsigned, origin, run){
 if (b == null) return null;
 var n = Clazz.doubleToInt(b.length / byteLen);
-var ret =  Clazz.newIntArray (rowCount == 0 ? n : rowCount, 0);
+var ret =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.ConditionalExpression*/rowCount == 0 ? n : rowCount, 0);
 var a = (run == null ? ret : run);
 var ii;
 switch (byteLen) {
@@ -274,7 +274,7 @@ origin = ret[i] = origin + ret[i];
 c$.unpackInts = Clazz.defineMethod(c$, "unpackInts", 
 function(b, byteLen, srcSize, unsigned, origin, run){
 if (b == null) return null;
-var ret =  Clazz.newIntArray (srcSize, 0);
+var ret =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/srcSize, 0);
 var a = (run == null ? ret : run);
 var max;
 switch (byteLen) {
@@ -317,7 +317,7 @@ origin = ret[i] = origin + ret[i];
 }, "~A,~N,~N,~B,~N,~A");
 c$.getTemp = Clazz.defineMethod(c$, "getTemp", 
 function(n){
-if (J.adapter.readers.cif.BCIFDecoder.temp == null || J.adapter.readers.cif.BCIFDecoder.temp.length < n) J.adapter.readers.cif.BCIFDecoder.temp =  Clazz.newIntArray (Math.max(n, 1000), 0);
+if (J.adapter.readers.cif.BCIFDecoder.temp == null || J.adapter.readers.cif.BCIFDecoder.temp.length < n) J.adapter.readers.cif.BCIFDecoder.temp =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.MethodInvocation*/Math.max(n, 1000), 0);
 return J.adapter.readers.cif.BCIFDecoder.temp;
 }, "~N");
 c$.clearTemp = Clazz.defineMethod(c$, "clearTemp", 
@@ -388,4 +388,4 @@ return sb.toString();
 }, "~A");
 c$.temp = null;
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
