@@ -174,21 +174,21 @@ return str;
 }, "~S");
 c$.getArrayFromStringList = Clazz.defineMethod(c$, "getArrayFromStringList", 
 function(s, n){
-var f =  Clazz.newFloatArray (n, 0);
+var f =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/n, 0);
 JU.PT.parseFloatArrayInfested(JU.PT.getTokens(s.$replace(',', ' ').$replace('[', ' ')), f);
-var d =  Clazz.newDoubleArray (n, 0);
+var d =  Clazz.newDoubleArray (/*org.eclipse.jdt.core.dom.SimpleName*/n, 0);
 for (var i = 0; i < n; i++) d[i] = f[i];
 
 return d;
 }, "~S,~N");
 c$.getIntArrayFromStringList = Clazz.defineMethod(c$, "getIntArrayFromStringList", 
 function(s, n){
-var f =  Clazz.newFloatArray (n, 0);
+var f =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/n, 0);
 JU.PT.parseFloatArrayInfested(JU.PT.getTokens(s.$replace(',', ' ').$replace('[', ' ')), f);
-var a =  Clazz.newIntArray (n, 0);
+var a =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/n, 0);
 for (var i = 0; i < n; i++) a[i] = Clazz.floatToInt(f[i]);
 
 return a;
 }, "~S,~N");
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
