@@ -6,4 +6,4 @@ function(){
 return  new J.adapter.readers.cif.Cif2DataParser().set(this, null, this.debugging);
 });
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
