@@ -145,7 +145,7 @@ if (this.htModulation.containsKey("X_" + this.atModel)) return;
 if (!isPost) {
 this.initModForStructure(iModel);
 return;
-}this.htModulation.put("X_" + this.atModel,  Clazz.newDoubleArray (0, 0));
+}this.htModulation.put("X_" + this.atModel,  Clazz.newDoubleArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/0, 0));
 this.cr.appendLoadNote(this.modCount + " modulations for " + this.ac + " modulated atoms");
 if (!this.haveAtomMods) return;
 var n = this.cr.asc.ac;
@@ -257,7 +257,7 @@ if (this.modAverage) break;
 var axis = key.charAt(pt_);
 type = this.getModType(key);
 if (this.htAtomMods == null) this.htAtomMods =  new java.util.Hashtable();
-var p =  Clazz.newDoubleArray (params.length, 0);
+var p =  Clazz.newDoubleArray (/*org.eclipse.jdt.core.dom.QualifiedName*/params.length, 0);
 for (var i = p.length; --i >= 0; ) p[i] = params[i];
 
 var qcoefs = this.getQCoefs(key);
@@ -292,7 +292,7 @@ var fn = ("STL0".indexOf(id) >= 0 ? 0 : this.cr.parseIntAt(key, 2));
 if (fn < 0) System.err.println("warning only -- MSRdr missing cell wave vector for atom wave vector for " + key + " 1 assumed");
 if (fn <= 0) {
 if (this.qlist100 == null) {
-this.qlist100 =  Clazz.newDoubleArray (this.modDim, 0);
+this.qlist100 =  Clazz.newDoubleArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.modDim, 0);
 this.qlist100[0] = 1;
 }return this.qlist100;
 }var p = this.getMod("F_" + fn + "_coefs_");
@@ -317,7 +317,7 @@ this.qs[i] = this.toP3(this.getMod("W_" + (i + 1)));
 for (var i = 0; i < this.modDim; i++) if (this.qs[i] != null) {
 var ifn = this.approxInt(pt.dot(this.qs[i]) / this.qs[i].dot(this.qs[i]));
 if (ifn != 0) {
-p =  Clazz.newDoubleArray (this.modDim, 0);
+p =  Clazz.newDoubleArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.modDim, 0);
 p[i] = ifn;
 return p;
 }}
@@ -332,7 +332,7 @@ pt.scale(i);
 if (this.modDim > 1 && this.qs[1] != null) pt.scaleAdd2(j, this.qs[1], pt);
 if (this.modDim > 2 && this.qs[2] != null) pt.scaleAdd2(k, this.qs[2], pt);
 if (pt.distanceSquared(p3) < 0.0001) {
-p =  Clazz.newDoubleArray (this.modDim, 0);
+p =  Clazz.newDoubleArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.modDim, 0);
 switch (this.modDim) {
 default:
 p[2] = k;
@@ -348,7 +348,7 @@ pt.scale(1 / i);
 if (this.modDim > 1 && this.qs[1] != null) pt.scaleAdd2(1 / j, this.qs[1], pt);
 if (this.modDim > 2 && this.qs[2] != null) pt.scaleAdd2(1 / k, this.qs[2], pt);
 if (pt.distanceSquared(p3) < 0.0001) {
-p =  Clazz.newDoubleArray (this.modDim, 0);
+p =  Clazz.newDoubleArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.modDim, 0);
 switch (this.modDim) {
 default:
 p[2] = 1 / k;
@@ -371,7 +371,7 @@ if (pt.y != 0) ifn = Math.max(this.approxInt(pt.y / p3.y), ifn);
 if (ifn == 0 && pt.z != 0) ifn = Math.max(this.approxInt(pt.z / p3.z), ifn);
 if (ifn == 0) continue;
 if (p3.x != 0 && this.approxInt(10 + p3.x * ifn - pt.x) == 0 || p3.y != 0 && this.approxInt(10 + p3.y * ifn - pt.y) == 0 || p3.z != 0 && this.approxInt(10 + p3.z * ifn - pt.z) == 0) continue;
-p =  Clazz.newDoubleArray (this.modDim, 0);
+p =  Clazz.newDoubleArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.modDim, 0);
 p[i] = ifn;
 return p;
 }
@@ -430,7 +430,7 @@ a.foccupancy = ms.setOccupancy(this.getMod("J_O#0;" + a.atomName), a.foccupancy,
 }if (ms.htUij != null) {
 var t = (a.tensors == null ? null : a.tensors.get(0));
 if (t != null && t.parBorU != null) {
-a.anisoBorU =  Clazz.newFloatArray (8, 0);
+a.anisoBorU =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/8, 0);
 for (var i = 0; i < 8; i++) a.anisoBorU[i] = t.parBorU[i];
 
 t.isUnmodulated = true;
@@ -593,4 +593,4 @@ if (a != null) lattvecs.addLast(a);
 return true;
 }, "JU.Lst,~S");
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Thu Sep 12 20:50:17 CDT 2024
