@@ -23,7 +23,7 @@ this.asc.setInfo("ignoreUnitCell", Boolean.TRUE);
 });
 Clazz.overrideMethod(c$, "processBinaryDocument", 
 function(){
-var bytes =  Clazz.newByteArray (40, 0);
+var bytes =  Clazz.newByteArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/40, 0);
 this.binaryDoc.setStream(null, this.binaryDoc.readInt() == 0x54);
 this.binaryDoc.readInt();
 this.nModels = this.binaryDoc.readInt();
@@ -70,7 +70,7 @@ return s.trim();
 Clazz.defineMethod(c$, "readFloatArray", 
 function(){
 var n = Clazz.doubleToInt(this.binaryDoc.readInt() / 4);
-var data =  Clazz.newFloatArray (n, 0);
+var data =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/n, 0);
 for (var i = 0; i < n; i++) data[i] = this.binaryDoc.readFloat();
 
 this.binaryDoc.readInt();
@@ -79,7 +79,7 @@ return data;
 Clazz.defineMethod(c$, "readDoubleArray", 
 function(){
 var n = Clazz.doubleToInt(this.binaryDoc.readInt() / 8);
-var data =  Clazz.newDoubleArray (n, 0);
+var data =  Clazz.newDoubleArray (/*org.eclipse.jdt.core.dom.SimpleName*/n, 0);
 for (var i = 0; i < n; i++) data[i] = this.binaryDoc.readDouble();
 
 this.binaryDoc.readInt();
@@ -149,4 +149,4 @@ System.out.println("unitcell:[" + a + " " + b + " " + c + " " + alpha + " " + be
 return  Clazz.newFloatArray(-1, [a, b, c, alpha, beta, gamma]);
 }, "~A");
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
