@@ -10,4 +10,4 @@ this.binaryDoc = null;
 this.isCDX = true;
 }, "J.adapter.readers.xml.XmlReader,~O");
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
