@@ -168,4 +168,4 @@ for (var i = 0; i < this.ac; ++i) this.setAtomCoord(atoms[this.nAtoms + i]);
 
 });
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
