@@ -19,4 +19,4 @@ this.finalizeReaderPDB();
 if (!this.useAltNames) this.asc.setCurrentModelInfo("altName", this.altNames.toArray( new Array(this.altNames.size())));
 });
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
