@@ -260,4 +260,4 @@ function(){
 return "[JmolObject " + this.id + " " + (this.bsAtoms == null ? "" : this.bsAtoms.cardinality() + " atoms") + "]";
 });
 });
-;//5.0.1-v4 Thu Aug 15 08:54:39 CDT 2024
+;//5.0.1-v4 Thu Sep 12 20:50:17 CDT 2024
