@@ -26,7 +26,7 @@ this.stack =  new JU.Lst();
 this.marks =  new JU.Lst();
 this.build =  new JU.Lst();
 this.memo =  new java.util.Hashtable();
-this.aTemp =  Clazz.newByteArray (16, 0);
+this.aTemp =  Clazz.newByteArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/16, 0);
 });
 Clazz.makeConstructor(c$, 
 function(doc, vwr){
@@ -108,7 +108,7 @@ this.push(o == null ? "LONG_BINGET" + (++this.id) : o);
 break;
 case 85:
 i = this.binaryDoc.readByte() & 0xff;
-a =  Clazz.newByteArray (i, 0);
+a =  Clazz.newByteArray (/*org.eclipse.jdt.core.dom.SimpleName*/i, 0);
 this.binaryDoc.readByteArray(a, 0, i);
 if (this.inNames && this.markCount == 3 && this.lastMark == this.stack.size()) {
 this.thisName = this.bytesToString(a);
@@ -117,13 +117,13 @@ this.filePt = this.emptyListPt;
 break;
 case 84:
 i = this.binaryDoc.readIntLE();
-a =  Clazz.newByteArray (i, 0);
+a =  Clazz.newByteArray (/*org.eclipse.jdt.core.dom.SimpleName*/i, 0);
 this.binaryDoc.readByteArray(a, 0, i);
 this.push(a);
 break;
 case 88:
 i = this.binaryDoc.readIntLE();
-a =  Clazz.newByteArray (i, 0);
+a =  Clazz.newByteArray (/*org.eclipse.jdt.core.dom.SimpleName*/i, 0);
 this.binaryDoc.readByteArray(a, 0, i);
 this.push(a);
 break;
@@ -305,4 +305,4 @@ function(){
 return this.stack.removeItemAt(this.stack.size() - 1);
 });
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
