@@ -162,7 +162,7 @@ while (this.rd() != null && this.line.length > 1) funcList += this.line;
 
 var tokens = JU.PT.getTokens(funcList);
 if (tokens.length != sd.nBF) return;
-sd.basisFunctions =  Clazz.newIntArray (tokens.length, 0);
+sd.basisFunctions =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.QualifiedName*/tokens.length, 0);
 for (var j = tokens.length; --j >= 0; ) {
 var n = this.parseIntStr(tokens[j]);
 if (n > nBF) nBF = n;
@@ -178,7 +178,7 @@ while (this.rd().indexOf("---") < 0) data += this.line;
 
 var tokens = JU.PT.getTokens(data);
 var nAtoms = tokens.length - 1;
-var atomList =  Clazz.newIntArray (nAtoms, 0);
+var atomList =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/nAtoms, 0);
 for (var i = 1; i <= nAtoms; i++) atomList[i - 1] = this.parseIntStr(tokens[i]) - 1;
 
 this.rd();
@@ -210,7 +210,7 @@ var ptSym = sd.index;
 var isLast = (ptSym == this.vSymmetries.size() - 1);
 var n = 0;
 var nBF = this.slaterArray.length;
-sd.coefs =  Clazz.newFloatArray (sd.nSFO, nBF, 0);
+sd.coefs =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.QualifiedName*/sd.nSFO, /*org.eclipse.jdt.core.dom.SimpleName*/nBF, 0);
 while (n < sd.nBF) {
 this.rd();
 var nLine = JU.PT.getTokens(this.rd()).length;
@@ -274,7 +274,7 @@ if (this.lastModel < 0) return;
 this.rd();
 this.rd();
 var n = this.asc.getAtomSetAtomCount(this.lastModel);
-var charges =  Clazz.newFloatArray (n, 0);
+var charges =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/n, 0);
 for (var i = 0; i < n; i++) {
 this.rd();
 var tokens = this.getTokens();
@@ -306,4 +306,4 @@ this.sym = sym;
 /*eoif4*/})();
 };
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Sat Sep 14 10:37:53 CDT 2024
