@@ -19,12 +19,13 @@ J.adapter.readers.quantum.BasisFunctionReader.$BasisFunctionReader$MOEnergySorte
 this.orbitalMaps = null;
 this.highLEnabled = null;
 this.nCoef = 0;
+this.haveCoefs = false;
 Clazz.instantialize(this, arguments);}, J.adapter.readers.quantum, "BasisFunctionReader", J.adapter.smarter.AtomSetCollectionReader);
 Clazz.prepareFields (c$, function(){
 this.moData =  new java.util.Hashtable();
 this.orbitals =  new JU.Lst();
 this.orbitalMaps =  new java.util.Hashtable();
-this.highLEnabled =  Clazz.newIntArray (J.quantum.QS.idSpherical.length, 0);
+this.highLEnabled =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.QualifiedName*/J.quantum.QS.idSpherical.length, 0);
 });
 Clazz.defineMethod(c$, "filterMO", 
 function(){
@@ -96,6 +97,7 @@ if (slater[1] == typeOld) slater[1] = typeNew;
 var m = this.getDfCoefMaps()[slater[1]].length;
 this.nCoef += m;
 }
+this.haveCoefs = true;
 return this.nCoef;
 }, "~N,~N");
 c$.getQuantumShellTagIDSpherical = Clazz.defineMethod(c$, "getQuantumShellTagIDSpherical", 
@@ -138,4 +140,4 @@ return (ea < eb ? -1 : ea > eb ? 1 : 0);
 /*eoif4*/})();
 };
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v4 Sat Sep 14 10:37:52 CDT 2024
