@@ -14,7 +14,7 @@ this.connectors = null;
 Clazz.instantialize(this, arguments);}, J.adapter.readers.quantum, "CsfReader", J.adapter.readers.quantum.MopacSlaterReader);
 Clazz.prepareFields (c$, function(){
 this.propertyItemCounts =  new java.util.Hashtable();
-this.fieldTypes =  Clazz.newIntArray (100, 0);
+this.fieldTypes =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/100, 0);
 });
 Clazz.overrideMethod(c$, "checkLine", 
 function(){
@@ -224,7 +224,7 @@ this.setBond(bond, this.connectors.get(thisBondID));
 });
 Clazz.defineMethod(c$, "processVibrationObject", 
 function(){
-var vibData =  Clazz.newFloatArray (this.nVibrations, this.nAtoms * 3, 0);
+var vibData =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.nVibrations, /*org.eclipse.jdt.core.dom.InfixExpression*/this.nAtoms * 3, 0);
 var energies =  new Array(this.nVibrations);
 this.rd();
 while (this.line != null && this.parseLineParameters(J.adapter.readers.quantum.CsfReader.vibFields, J.adapter.readers.quantum.CsfReader.vibFieldMap) > 0) {
@@ -264,9 +264,9 @@ this.rd();
 return;
 }this.nOrbitals = (this.nSlaters + this.nGaussians);
 JU.Logger.info("Reading CSF data for " + this.nOrbitals + " molecular orbitals");
-var energy =  Clazz.newFloatArray (this.nOrbitals, 0);
-var occupancy =  Clazz.newFloatArray (this.nOrbitals, 0);
-var list =  Clazz.newFloatArray (this.nOrbitals, this.nOrbitals, 0);
+var energy =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.nOrbitals, 0);
+var occupancy =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.nOrbitals, 0);
+var list =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.nOrbitals, /*org.eclipse.jdt.core.dom.SimpleName*/this.nOrbitals, 0);
 var listCompressed = null;
 var coefIndices = null;
 var ipt = 0;
@@ -290,11 +290,11 @@ this.fillCsfArray("eig_vec", tokens, i, list[ipt], false);
 break;
 case 4:
 isCompressed = true;
-if (listCompressed == null) listCompressed =  Clazz.newFloatArray (this.nOrbitals, this.nOrbitals, 0);
+if (listCompressed == null) listCompressed =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.nOrbitals, /*org.eclipse.jdt.core.dom.SimpleName*/this.nOrbitals, 0);
 this.fillCsfArray("eig_vec_compressed", tokens, i, listCompressed[ipt], false);
 break;
 case 5:
-if (coefIndices == null) coefIndices =  Clazz.newIntArray (this.nOrbitals, this.nOrbitals, 0);
+if (coefIndices == null) coefIndices =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.nOrbitals, /*org.eclipse.jdt.core.dom.SimpleName*/this.nOrbitals, 0);
 this.fillCsfArray("coef_indices", tokens, i, coefIndices[ipt], true);
 break;
 }
@@ -321,7 +321,7 @@ this.setMOs("eV");
 Clazz.defineMethod(c$, "processBasisObject", 
 function(sto_gto){
 var atomNos = JU.PT.getTokens(this.strAtomicNumbers);
-this.atomicNumbers =  Clazz.newIntArray (atomNos.length, 0);
+this.atomicNumbers =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.QualifiedName*/atomNos.length, 0);
 for (var i = 0; i < this.atomicNumbers.length; i++) this.atomicNumbers[i] = this.parseIntStr(atomNos[i]);
 
 this.nOrbitals = (this.nSlaters + this.nGaussians);
@@ -329,7 +329,7 @@ var isGaussian = (sto_gto.equals("gto"));
 var zetas = JU.AU.newFloat2(this.nOrbitals);
 var contractionCoefs = null;
 var types =  new Array(this.nOrbitals);
-var shells =  Clazz.newIntArray (this.nOrbitals, 0);
+var shells =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.nOrbitals, 0);
 var nZetas = 0;
 this.rd();
 while (this.line != null && this.parseLineParameters(J.adapter.readers.quantum.CsfReader.moFields, J.adapter.readers.quantum.CsfReader.moFieldMap) > 0) {
@@ -348,14 +348,14 @@ types[ipt] = field;
 break;
 case 7:
 case 9:
-zetas[ipt] =  Clazz.newFloatArray (nZetas, 0);
+zetas[ipt] =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/nZetas, 0);
 this.fillCsfArray(sto_gto + "_exp", tokens, i, zetas[ipt], false);
 break;
 case 10:
 shells[ipt] = this.parseIntStr(field);
 break;
 case 8:
-if (contractionCoefs == null) contractionCoefs =  Clazz.newFloatArray (this.nOrbitals, nZetas, 0);
+if (contractionCoefs == null) contractionCoefs =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.nOrbitals, /*org.eclipse.jdt.core.dom.SimpleName*/nZetas, 0);
 this.fillCsfArray("contractions", tokens, i, contractionCoefs[ipt], false);
 }
 }
@@ -369,7 +369,7 @@ var gaussianCount = 0;
 for (var ipt = 0; ipt < this.nGaussians; ipt++) {
 if (shells[ipt] != iShell) {
 iShell = shells[ipt];
-var slater =  Clazz.newIntArray (4, 0);
+var slater =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/4, 0);
 var iAtom = this.asc.getAtomIndex(this.connectors.get(sto_gto + "_basis_fxn" + (ipt + 1))[0]);
 slater[0] = iAtom + 1;
 slater[1] = J.adapter.readers.quantum.BasisFunctionReader.getQuantumShellTagID(types[ipt].substring(0, 1));
@@ -409,4 +409,4 @@ c$.vibFieldMap =  Clazz.newByteArray(-1, [-1, 1, 2, 3]);
 c$.moFields =  Clazz.newArray(-1, ["ID", "eig_val", "mo_occ", "eig_vec", "eig_vec_compressed", "coef_indices", "bfxn_ang", "sto_exp", "contractions", "gto_exp", "shell"]);
 c$.moFieldMap =  Clazz.newByteArray(-1, [-1, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10]);
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Sat Sep 14 10:37:53 CDT 2024
