@@ -93,7 +93,7 @@ slatersByAtomType.addLast(slater);
 this.gaussians = JU.AU.newFloat2(this.gaussianCount);
 for (var i = 0; i < this.gaussianCount; i++) {
 tokens = gdata.get(i);
-this.gaussians[i] =  Clazz.newFloatArray (tokens.length - 3, 0);
+this.gaussians[i] =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.InfixExpression*/tokens.length - 3, 0);
 for (var j = 3; j < tokens.length; j++) this.gaussians[i][j - 3] = this.parseFloatStr(tokens[j]);
 
 }
@@ -122,7 +122,7 @@ var haveFreq = false;
 while (this.line != null && this.line.indexOf("FREQUENCY:") >= 0) {
 var frequencyCount = 0;
 var tokens = this.getTokens();
-var frequencies =  Clazz.newFloatArray (tokens.length, 0);
+var frequencies =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.QualifiedName*/tokens.length, 0);
 for (var i = 0; i < tokens.length; i++) {
 var frequency = this.parseFloatStr(tokens[i]);
 if (tokens[i].equals("I")) frequencies[frequencyCount - 1] = -frequencies[frequencyCount - 1];
@@ -285,4 +285,4 @@ throw e;
 }
 }, "~S");
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Sat Sep 14 10:37:53 CDT 2024
