@@ -185,4 +185,4 @@ JU.Logger.info("Molecular dipole for model " + this.asc.atomSetCount + " = " + d
 this.asc.setCurrentModelInfo("dipole", dipole);
 }});
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v4 Sat Sep 14 10:37:53 CDT 2024
