@@ -65,7 +65,7 @@ throw e;
 });
 Clazz.defineMethod(c$, "fillFloat", 
 function(f0, i, n){
-var f =  Clazz.newFloatArray (n, 0);
+var f =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/n, 0);
 for (var i1 = 0, ilast = i + n; i < ilast; i++, i1++) f[i1] = f0[i];
 
 return f;
@@ -87,7 +87,7 @@ if (isArray) {
 switch ((type).charCodeAt(0)) {
 case 73:
 case 82:
-o = this.fillFloatArray(null, 0,  Clazz.newFloatArray (this.parseIntStr(v), 0));
+o = this.fillFloatArray(null, 0,  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.MethodInvocation*/this.parseIntStr(v), 0));
 this.line = null;
 break;
 default:
@@ -192,7 +192,7 @@ for (var i = 0; i < this.shellCount; i++) {
 var oType = J.adapter.readers.quantum.GaussianFchkReader.AO_TYPES[Clazz.floatToInt(types[i]) + 3];
 var nGaussians = Clazz.floatToInt(pps[i]);
 var iatom = Clazz.floatToInt(atomMap[i]);
-var slater =  Clazz.newIntArray (4, 0);
+var slater =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/4, 0);
 slater[0] = iatom;
 if (oType.equals("F7") || oType.equals("D5")) slater[1] = J.adapter.readers.quantum.BasisFunctionReader.getQuantumShellTagIDSpherical(oType.substring(0, 1));
  else slater[1] = J.adapter.readers.quantum.BasisFunctionReader.getQuantumShellTagID(oType);
@@ -201,7 +201,7 @@ slater[3] = nGaussians;
 if (this.debugging) JU.Logger.debug("Slater " + this.shells.size() + " " + JU.Escape.eAI(slater));
 this.shells.addLast(slater);
 for (var j = 0; j < nGaussians; j++) {
-var g = this.gaussians[this.gaussianCount] =  Clazz.newFloatArray (3, 0);
+var g = this.gaussians[this.gaussianCount] =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/3, 0);
 g[0] = exps[this.gaussianCount];
 g[1] = coefs[this.gaussianCount];
 if (spcoefs != null) g[2] = spcoefs[this.gaussianCount];
@@ -237,7 +237,7 @@ this.alphaBeta = (occ == 2 ? "" : this.alphaBeta.equals("alpha") ? "beta" : "alp
 var pt = 0;
 var n = 0;
 for (var i = 0; i < nOrb; i++) {
-var coefs =  Clazz.newFloatArray (nCoef, 0);
+var coefs =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/nCoef, 0);
 for (var j = 0; j < nCoef; j++) coefs[j] = c[pt++];
 
 var mo =  new java.util.Hashtable();
@@ -252,4 +252,4 @@ this.setMO(mo);
 }, "~A,~A,~N,~N");
 c$.AO_TYPES =  Clazz.newArray(-1, ["F7", "D5", "L", "S", "P", "D", "F", "G", "H"]);
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Sat Sep 14 10:37:53 CDT 2024
