@@ -108,7 +108,7 @@ this.appendLoadNote("\nfilter: " + this.filter);
 Clazz.defineMethod(c$, "getSpinDensities", 
 function(pt){
 this.rd();
-var data =  Clazz.newFloatArray (this.asc.getLastAtomSetAtomCount(), 0);
+var data =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.MethodInvocation*/this.asc.getLastAtomSetAtomCount(), 0);
 for (var i = 0; i < data.length; i++) data[i] = this.parseFloatStr(this.rd().substring(pt, pt + 10));
 
 this.asc.setAtomProperties("spin", data, -1, false);
@@ -185,7 +185,7 @@ this.shellCount++;
 tokens = this.getTokens();
 ac++;
 while (this.rd().indexOf("****") < 0) {
-var slater =  Clazz.newIntArray (4, 0);
+var slater =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/4, 0);
 slater[0] = ac;
 tokens = this.getTokens();
 var oType = tokens[0];
@@ -210,7 +210,7 @@ gdata.addLast(tokens);
 while (this.rd() != null && this.line.startsWith(" Atom")) {
 this.shellCount++;
 tokens = this.getTokens();
-var slater =  Clazz.newIntArray (4, 0);
+var slater =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/4, 0);
 if (!tokens[1].equals(lastAtom)) ac++;
 lastAtom = tokens[1];
 slater[0] = ac;
@@ -231,7 +231,7 @@ gdata.addLast(JU.PT.getTokens(this.rd()));
 this.gaussians = JU.AU.newFloat2(this.gaussianCount);
 for (var i = 0; i < this.gaussianCount; i++) {
 tokens = gdata.get(i);
-this.gaussians[i] =  Clazz.newFloatArray (tokens.length, 0);
+this.gaussians[i] =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.QualifiedName*/tokens.length, 0);
 for (var j = 0; j < tokens.length; j++) this.gaussians[i][j] = this.parseFloatStr(tokens[j]);
 
 }
@@ -313,7 +313,7 @@ this.line = this.rd();
 var ac = this.asc.getLastAtomSetAtomCount();
 var data =  new Array(ac);
 var temp = null;
-var atomIndices =  Clazz.newIntArray (ac, 0);
+var atomIndices =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/ac, 0);
 while (this.line != null && this.line.length > 20 && this.line.indexOf("Temperature") < 0) {
 var symmetries = JU.PT.getTokens(this.rd());
 this.discardLinesUntilContains(" Frequencies");
@@ -398,7 +398,7 @@ this.appendLoadNote("NMR shift tensors are available for model=" + (this.asc.iSe
 Clazz.defineMethod(c$, "addTensor", 
 function(iatom, data){
 var i0 = this.asc.getLastAtomSetAtomIndex();
-var a =  Clazz.newDoubleArray (3, 3, 0);
+var a =  Clazz.newDoubleArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/3, /*org.eclipse.jdt.core.dom.NumberLiteral*/3, 0);
 for (var i = 0, p = 1; i < 3; i++) {
 for (var j = 0; j < 3; j++, p++) {
 a[i][j] = this.parseFloatStr(data[p]);
@@ -412,7 +412,7 @@ Clazz.defineMethod(c$, "readCouplings",
 function(){
 var type = (this.line.indexOf(" K ") >= 0 ? "K" : "J");
 var n = this.asc.getLastAtomSetAtomCount();
-var data =  Clazz.newFloatArray (n, n, 0);
+var data =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/n, /*org.eclipse.jdt.core.dom.SimpleName*/n, 0);
 var k0 = 0;
 while (true) {
 this.rd();
@@ -434,4 +434,4 @@ this.asc.setAtomProperties("J", data, this.asc.iSet, false);
 this.appendLoadNote("NMR J Couplings saved for model=" + (this.asc.iSet + 1) + " as property_J;\n use set measurementUnits \"+hz\" to measure them.");
 }});
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Sat Sep 14 10:37:53 CDT 2024
