@@ -67,7 +67,7 @@ Clazz.defineMethod(c$, "readUnnormalizedBasis",
 function(){
 var lastAtom = "";
 var iAtom = 0;
-var sdata =  Clazz.newIntArray (this.moCount, 4, 0);
+var sdata =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.moCount, /*org.eclipse.jdt.core.dom.NumberLiteral*/4, 0);
 var sgdata = JU.AU.createArrayOfArrayList(this.moCount);
 var tokens;
 this.gaussianCount = 0;
@@ -188,7 +188,7 @@ var n = eigenValues.length - 1;
 this.fillDataBlock(dataBlock, 0);
 var occ = 2;
 for (var iOrb = 0; iOrb < n; iOrb++) {
-var coefs =  Clazz.newFloatArray (this.moCount, 0);
+var coefs =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.moCount, 0);
 var mo =  new java.util.Hashtable();
 var energy = this.parseFloatStr(eigenValues[iOrb + 1]);
 mo.put("energy", Float.$valueOf(energy));
@@ -244,4 +244,4 @@ this.haveLine = false;
 return this.line;
 });
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Sat Sep 14 10:37:53 CDT 2024
