@@ -142,7 +142,7 @@ if (fCoeffLabels.indexOf("X") >= 0) isOK = this.getDFMap("FC", fCoeffLabels, 6,
 if (nBlank == 2) break;
 if (str.indexOf("LZ VALUE") >= 0) this.discardLinesUntilBlank();
 for (var iMo = 0; iMo < nThisLine; iMo++) {
-var coefs =  Clazz.newFloatArray (data[iMo].size(), 0);
+var coefs =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.MethodInvocation*/data[iMo].size(), 0);
 var iCoeff = 0;
 while (iCoeff < coefs.length) {
 coefs[iCoeff] = this.parseFloatStr(data[iMo].get(iCoeff));
@@ -260,7 +260,7 @@ for (var i = 0; i < nThisLine; i++) mos[i].put("symmetry", tokens[i]);
 Clazz.defineMethod(c$, "addMOData", 
 function(nColumns, data, mos){
 for (var i = 0; i < nColumns; i++) {
-var coefs =  Clazz.newFloatArray (data[i].size(), 0);
+var coefs =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.MethodInvocation*/data[i].size(), 0);
 for (var j = coefs.length; --j >= 0; ) coefs[j] = this.parseFloatStr(data[i].get(j));
 
 mos[i].put("coefficients", coefs);
@@ -292,7 +292,7 @@ while (this.rd() != null && this.line.indexOf("NBO") < 0) {
 if (this.line.length < 5 || this.line.charAt(4) != '.') continue;
 strSecondOrderData.addLast( Clazz.newArray(-1, [JU.PT.rep(this.line.substring(5, 27).trim(), " ", ""), JU.PT.rep(this.line.substring(32, 54).trim(), " ", ""), this.line.substring(55, 62).trim(), this.line.substring(71).trim()]));
 }
-var secondOrderData =  Clazz.newFloatArray (strSecondOrderData.size(), 4, 0);
+var secondOrderData =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.MethodInvocation*/strSecondOrderData.size(), /*org.eclipse.jdt.core.dom.NumberLiteral*/4, 0);
 this.lastMoData.put("secondOrderData", secondOrderData);
 this.lastMoData = null;
 var IMO;
@@ -308,4 +308,4 @@ secondOrderData[i][3] = this.parseFloatStr(a[3]);
 });
 c$.FC_LIST = "(F1)  (F2)  (F10) (F4)  (F2)  (F3)  (F6)  (F9)  (F8)  (F5)";
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Sat Sep 14 10:37:53 CDT 2024
