@@ -72,7 +72,7 @@ for (var i = 0; i < 6; i++) this.setUnitCellItem(i, this.parseFloat());
 this.rd();
 return true;
 }if (this.line.startsWith("[CELLAXES]")) {
-var f =  Clazz.newFloatArray (9, 0);
+var f =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/9, 0);
 this.fillFloatArray(null, 0, f);
 this.addExplicitLatticeVector(0, f, 0);
 this.addExplicitLatticeVector(1, f, 3);
@@ -152,7 +152,7 @@ var gdata =  new JU.Lst();
 var atomIndex = 0;
 var gaussianPtr = 0;
 this.nCoef = 0;
-this.nSPDF =  Clazz.newIntArray (12, 0);
+this.nSPDF =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/12, 0);
 this.discardLinesUntilNonBlank();
 while (this.line != null && !((this.line = this.line.trim()).length == 0 || this.line.charAt(0) == '[')) {
 var tokens = this.getTokens();
@@ -166,16 +166,20 @@ tokens = this.getTokens();
 var shellLabel = tokens[0].toUpperCase();
 var type = J.adapter.readers.quantum.BasisFunctionReader.getQuantumShellTagID(shellLabel);
 var nPrimitives = this.parseIntStr(tokens[1]);
-var slater =  Clazz.newIntArray (4, 0);
+var slater =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/4, 0);
 this.nSPDF[type]++;
 slater[0] = atomIndex + 1;
 slater[1] = type;
 slater[2] = gaussianPtr + 1;
 slater[3] = nPrimitives;
-for (var ip = nPrimitives; --ip >= 0; ) {
+var n = this.getDfCoefMaps()[type].length;
+if (!this.haveCoefs) {
+System.out.println(this.nCoef + " adding " + n + " coefficients type " + J.adapter.readers.quantum.BasisFunctionReader.getQuantumShellTag(type) + " for atom " + atomIndex);
+this.nCoef += n;
+}for (var ip = nPrimitives; --ip >= 0; ) {
 var primTokens = JU.PT.getTokens(this.rd());
 var nTokens = primTokens.length;
-var orbData =  Clazz.newFloatArray (nTokens, 0);
+var orbData =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/nTokens, 0);
 for (var d = 0; d < nTokens; d++) orbData[d] = this.parseFloatStr(primTokens[d]);
 
 gdata.addLast(orbData);
@@ -243,7 +247,7 @@ this.checkOrbitalType("[5D]");
 }while (++pt <= this.nCoef) {
 data.addLast("0");
 }
-var coefs =  Clazz.newFloatArray (this.nCoef, 0);
+var coefs =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.nCoef, 0);
 for (var i = data.size(); --i >= 0; ) coefs[i] = this.parseFloatStr(data.get(i));
 
 var l = this.line;
@@ -402,4 +406,4 @@ for (var i = 0; i < this.modelAtomCount; i++) this.setAtomCoordScaled(atoms[i +
 
 }, "~S,~B,~B");
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Sat Sep 14 10:37:53 CDT 2024
