@@ -26,7 +26,7 @@ Clazz.defineMethod(c$, "readAtoms",
 function(){
 this.asc.newAtomSet();
 this.ac = this.parseIntStr(this.line);
-this.atomicNumbers =  Clazz.newIntArray (this.ac, 0);
+this.atomicNumbers =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.ac, 0);
 for (var i = 0; i < this.ac; i++) {
 this.rd();
 this.atomicNumbers[i] = this.parseIntRange(this.line, 0, 4);
@@ -40,7 +40,7 @@ Clazz.defineMethod(c$, "readSlaterBasis",
 function(){
 this.nCoefficients = 0;
 this.getSlaters();
-var values =  Clazz.newFloatArray (3, 0);
+var values =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/3, 0);
 for (var iAtom = 0; iAtom < this.ac; iAtom++) {
 J.adapter.smarter.AtomSetCollectionReader.getTokensFloat(this.rd(), values, 3);
 var atomicNumber = this.atomicNumbers[iAtom];
@@ -59,13 +59,13 @@ if (this.isNewFormat) {
 this.orbitalData =  new JU.Lst();
 if (this.line.length > 10) this.orbitalInfo =  new JU.Lst();
 } else {
-list =  Clazz.newFloatArray (this.nCoefficients, this.nCoefficients, 0);
+list =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.nCoefficients, /*org.eclipse.jdt.core.dom.SimpleName*/this.nCoefficients, 0);
 }for (var iMo = 0; iMo < this.nCoefficients; iMo++) {
 if (iMo != 0) this.rd();
 var data;
 if (this.isNewFormat) {
 if (this.line == null || this.line.indexOf("ORBITAL") < 0 || this.line.indexOf("ORBITAL_LIST") >= 0) break;
-this.orbitalData.addLast(data =  Clazz.newFloatArray (this.nCoefficients, 0));
+this.orbitalData.addLast(data =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.nCoefficients, 0));
 if (this.orbitalInfo != null) this.orbitalInfo.addLast(this.line);
 this.rd();
 } else {
@@ -75,14 +75,14 @@ data = list[iMo];
 if (this.invMatrix == null) {
 if (this.isNewFormat && this.line.indexOf("MATRIX") < 0) this.rd();
 this.invMatrix = JU.AU.newFloat2(this.nCoefficients);
-for (var iMo = 0; iMo < this.nCoefficients; iMo++) this.fillFloatArray(null, 15, this.invMatrix[iMo] =  Clazz.newFloatArray (iMo + 1, 0));
+for (var iMo = 0; iMo < this.nCoefficients; iMo++) this.fillFloatArray(null, 15, this.invMatrix[iMo] =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.InfixExpression*/iMo + 1, 0));
 
 }this.nOrbitals = (this.orbitalData == null ? this.nCoefficients : this.orbitalData.size());
 if (this.orbitalData != null) {
 list = JU.AU.newFloat2(this.nOrbitals);
 for (var i = this.nOrbitals; --i >= 0; ) list[i] = this.orbitalData.get(i);
 
-}var list2 =  Clazz.newFloatArray (this.nOrbitals, this.nCoefficients, 0);
+}var list2 =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.nOrbitals, /*org.eclipse.jdt.core.dom.SimpleName*/this.nCoefficients, 0);
 for (var i = 0; i < this.nOrbitals; i++) for (var j = 0; j < this.nCoefficients; j++) {
 for (var k = 0; k < this.nCoefficients; k++) list2[i][j] += (list[i][k] * (k >= j ? this.invMatrix[k][j] : this.invMatrix[j][k]));
 
@@ -90,7 +90,7 @@ if (Math.abs(list2[i][j]) < 1.0E-4) list2[i][j] = 0;
 }
 
 if (this.isNewFormat && this.orbitalInfo == null && this.line != null && this.line.indexOf("ORBITAL_LIST") < 0) this.rd();
-var values =  Clazz.newFloatArray (2, 0);
+var values =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/2, 0);
 for (var iMo = 0; iMo < this.nOrbitals; iMo++) {
 var mo =  new java.util.Hashtable();
 if (this.orbitalInfo != null) {
@@ -121,4 +121,4 @@ this.orbitals.get(i).put("type", "alpha");
 }return isUHF;
 });
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v4 Sat Sep 14 10:37:53 CDT 2024
