@@ -311,7 +311,7 @@ case 70:
 this.nBasisFunctions += nF;
 break;
 }
-var slater =  Clazz.newIntArray (4, 0);
+var slater =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/4, 0);
 slater[0] = i + 1;
 slater[1] = (isD6F10 ? J.adapter.readers.quantum.BasisFunctionReader.getQuantumShellTagID(type) : J.adapter.readers.quantum.BasisFunctionReader.getQuantumShellTagIDSpherical(type));
 slater[2] = this.gaussianCount + 1;
@@ -368,7 +368,7 @@ if (symmetry != null) mo.put("symmetry", symmetry);
 var coefs = null;
 this.setMO(mo);
 mo.put("type", this.alphaBeta + (++moCount));
-coefs =  Clazz.newFloatArray (this.nBasisFunctions, 0);
+coefs =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.nBasisFunctions, 0);
 mo.put("coefficients", coefs);
 i += 3;
 while ((this.line = list.get(++i)) != null && this.line.length > 3) {
@@ -404,4 +404,4 @@ c$.$FS_LIST = "f3-   f2-   f1-   f0    f1+   f2+   f3+";
 c$.$DC_LIST = "DXX   DXY   DXZ   DYY   DYZ   DZZ";
 c$.$FC_LIST = "XXX   XXY   XXZ   XYY   XYZ   XZZ   YYY   YYZ   YZZ   ZZZ";
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v4 Sat Sep 14 10:37:53 CDT 2024
