@@ -98,7 +98,7 @@ var lines = basisLines.get(this.asc.atoms[ac].elementSymbol);
 for (var j = 0; j < lines.size(); ) {
 var tokens = lines.get(j++);
 this.shellCount++;
-var slater =  Clazz.newIntArray (4, 0);
+var slater =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/4, 0);
 slater[0] = ac + 1;
 var oType = tokens[0];
 if (doSphericalF && oType.indexOf("F") >= 0 || doSphericalD && oType.indexOf("D") >= 0) slater[1] = J.adapter.readers.quantum.BasisFunctionReader.getQuantumShellTagIDSpherical(oType);
@@ -119,7 +119,7 @@ gdata.addLast(tokens);
 this.gaussians = JU.AU.newFloat2(this.gaussianCount);
 for (var i = 0; i < this.gaussianCount; i++) {
 var tokens = gdata.get(i);
-this.gaussians[i] =  Clazz.newFloatArray (tokens.length, 0);
+this.gaussians[i] =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.QualifiedName*/tokens.length, 0);
 for (var j = 0; j < tokens.length; j++) this.gaussians[i][j] = this.parseFloatStr(tokens[j]);
 
 }
@@ -192,4 +192,4 @@ d.add(i + 2, s);
 this.addMOData(nThisLine, data, mos);
 }, "~N,JU.Lst,~A,~A");
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Sat Sep 14 10:37:53 CDT 2024
