@@ -88,7 +88,7 @@ case 3:
 if (slater != null) {
 slatersByUniqueAtom.addLast(slater);
 }ipt = 1;
-slater =  Clazz.newIntArray (3, 0);
+slater =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/3, 0);
 slater[0] = J.adapter.readers.quantum.BasisFunctionReader.getQuantumShellTagID(tokens[0]);
 slater[1] = this.gaussianCount;
 this.shellCount++;
@@ -109,7 +109,7 @@ this.rd();
 var garray = JU.AU.newFloat2(this.gaussianCount);
 for (var i = 0; i < this.gaussianCount; i++) {
 tokens = gdata.get(i);
-garray[i] =  Clazz.newFloatArray (tokens.length, 0);
+garray[i] =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.QualifiedName*/tokens.length, 0);
 for (var j = 0; j < tokens.length; j++) garray[i][j] = this.parseFloatStr(tokens[j]);
 
 }
@@ -199,4 +199,4 @@ this.rd();
 }
 });
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Sat Sep 14 10:37:53 CDT 2024
