@@ -40,7 +40,7 @@ JU.Logger.debug("SlaterReader " + i + ": " + sd.atomNo + " " + sd.x + " " + sd.y
 }}
 if (doSort) {
 java.util.Arrays.sort(this.slaterArray, Clazz.innerTypeInstance(J.adapter.readers.quantum.SlaterReader.SlaterSorter, this, null));
-var pointers =  Clazz.newIntArray (this.slaterArray.length, 0);
+var pointers =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.QualifiedName*/this.slaterArray.length, 0);
 for (var i = 0; i < this.slaterArray.length; i++) pointers[i] = this.slaterArray[i].index;
 
 this.sortOrbitalCoefficients(pointers);
@@ -58,7 +58,7 @@ function(pointers){
 for (var i = this.orbitals.size(); --i >= 0; ) {
 var mo = this.orbitals.get(i);
 var coefs = mo.get("coefficients");
-var sorted =  Clazz.newFloatArray (pointers.length, 0);
+var sorted =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.QualifiedName*/pointers.length, 0);
 for (var j = 0; j < pointers.length; j++) {
 var k = pointers[j];
 if (k < coefs.length) sorted[j] = coefs[k];
@@ -121,4 +121,4 @@ return (e1 < e2 ? -1 : e2 < e1 ? 1 : 0);
 c$.fact_2n =  Clazz.newDoubleArray(-1, [1, 2, 24, 720, 40320, 3628800, 479001600]);
 c$.dfact2 =  Clazz.newDoubleArray(-1, [1, 1, 3, 15, 105]);
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Sat Sep 14 10:37:53 CDT 2024
