@@ -112,7 +112,7 @@ while (this.getLine()) {
 var tokens = this.getTokens();
 if (tokens.length == 0) continue;
 if (tokens.length != 1) throw  new Exception("Error reading GTOs: missing atom index");
-var slater =  Clazz.newIntArray (4, 0);
+var slater =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/4, 0);
 atomNo = this.parseIntStr(tokens[0]);
 tokens = JU.PT.getTokens(this.rd());
 var nGaussians = this.parseIntStr(tokens[1]);
@@ -123,7 +123,7 @@ slater[3] = nGaussians;
 for (var i = 0; i < nGaussians; i++) {
 var strData = JU.PT.getTokens(this.rd());
 var nData = strData.length;
-var data =  Clazz.newFloatArray (nData, 0);
+var data =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/nData, 0);
 for (var d = 0; d < nData; d++) {
 data[d] = this.parseFloatStr(strData[d]);
 }
@@ -170,7 +170,7 @@ if (tokens.length == 0) {
 continue;
 }data.addLast(tokens[1]);
 }
-var coefs =  Clazz.newFloatArray (data.size(), 0);
+var coefs =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.MethodInvocation*/data.size(), 0);
 for (var i = data.size(); --i >= 0; ) {
 coefs[i] = this.parseFloatStr(data.get(i));
 }
@@ -186,4 +186,4 @@ c$.$DC_LIST = "xx    yy    zz    xy    xz    yz";
 c$.$FS_LIST = "NOT IMPLEMENTED IN THIS READER";
 c$.$FC_LIST = "xxx   yyy   zzz   yyx   xxy   xxz   zzx   zzy   yyz   xyz";
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Sat Sep 14 10:37:53 CDT 2024
