@@ -53,7 +53,7 @@ atoms[i].partialCharge = this.partialCharges[i % this.ac];
 Clazz.defineMethod(c$, "readPartialCharges", 
 function(){
 this.rd();
-this.partialCharges =  Clazz.newFloatArray (this.ac, 0);
+this.partialCharges =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.ac, 0);
 var tokens;
 for (var i = 0; i < this.ac; i++) {
 if (this.rd() == null || (tokens = this.getTokens()).length < 4) break;
@@ -86,4 +86,4 @@ this.rd();
 }
 });
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
