@@ -41,4 +41,4 @@ this.setAtomCoordScaled(null, tokens, 2, f).elementNumber = this.parseIntStr(tok
 }
 });
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
