@@ -87,4 +87,4 @@ atoms[i].partialCharge = this.parseFloat();
 }
 });
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
