@@ -122,8 +122,8 @@ var a = this.addAtomXYZSymName(this.tokens, 2, null, null);
 a.elementNumber = Clazz.floatToShort(this.getValue(1));
 map.put(this.tokens[0], a);
 }
-var bonds = this.fillFloatArray(null, 0,  Clazz.newFloatArray (nBonds * 2, 0));
-var orders = this.fillFloatArray(null, 0,  Clazz.newFloatArray (nBonds, 0));
+var bonds = this.fillFloatArray(null, 0,  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.InfixExpression*/nBonds * 2, 0));
+var orders = this.fillFloatArray(null, 0,  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/nBonds, 0));
 for (var i = 0, pt = 0; i < nBonds; i++) this.asc.addBond( new J.adapter.smarter.Bond(map.get("" + Clazz.floatToInt(bonds[pt++])).index, map.get("" + Clazz.floatToInt(bonds[pt++])).index, Clazz.floatToInt(orders[i])));
 
 });
@@ -317,4 +317,4 @@ this.v2.setT(list.get(1));
 return atom;
 }, "J.adapter.smarter.Atom,~N,~N,~N,~N,~N,~N");
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
