@@ -66,7 +66,7 @@ this.setSpaceGroupName("P1");
 var nTv = this.vAtoms.size() - this.ac;
 for (var i = nTv; i < 3; i++) this.vAtoms.addLast( new J.adapter.smarter.Atom());
 
-var xyz =  Clazz.newFloatArray (9, 0);
+var xyz =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/9, 0);
 for (var i = 0; i < 3; i++) {
 var j = i * 3;
 atom = this.vAtoms.get(this.ac + i);
@@ -107,4 +107,4 @@ for (var i = this.ac; --i >= 0; ) this.vAtoms.get(i).add(ptCenter);
 }return true;
 });
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
