@@ -2,4 +2,4 @@ Clazz.declarePackage("J.adapter.readers.simple");
 Clazz.load(["J.adapter.readers.simple.FoldingXyzReader"], "J.adapter.readers.simple.TinkerReader", null, function(){
 var c$ = Clazz.declareType(J.adapter.readers.simple, "TinkerReader", J.adapter.readers.simple.FoldingXyzReader);
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
