@@ -11,4 +11,4 @@ if (this.line != null && this.line.indexOf("MOLSTATE") >= 0) this.readTransform(
 this.continuing = false;
 });
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Sat Sep 14 10:37:53 CDT 2024
