@@ -120,11 +120,11 @@ Clazz.defineMethod(c$, "readBasis",
 function(){
 var shells =  new JU.Lst();
 var gaussians = JU.AU.newFloat2(this.gaussianCount);
-var typeArray =  Clazz.newIntArray (this.gaussianCount, 0);
+var typeArray =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.gaussianCount, 0);
 for (var i = 0; i < this.shellCount; i++) {
 var tokens = JU.PT.getTokens(this.readLine());
 var isSpherical = (tokens[4].charAt(0) == '1');
-var slater =  Clazz.newIntArray (4, 0);
+var slater =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/4, 0);
 slater[0] = this.parseInt(tokens[3]);
 var iBasis = this.parseInt(tokens[0]);
 switch (iBasis) {
@@ -153,7 +153,7 @@ for (var i = 0; i < this.gaussianCount; i++) {
 var alpha = this.parseFloat(this.readLine());
 var tokens = JU.PT.getTokens(this.readLine());
 var nData = tokens.length;
-var data =  Clazz.newFloatArray (nData + 1, 0);
+var data =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.InfixExpression*/nData + 1, 0);
 data[0] = alpha;
 switch (typeArray[i]) {
 case 0:
@@ -231,8 +231,8 @@ function(){
 var tokenPt = 0;
 this.r.orbitals =  new JU.Lst();
 var tokens = JU.PT.getTokens("");
-var energies =  Clazz.newFloatArray (this.moCount, 0);
-var coefficients =  Clazz.newFloatArray (this.moCount, this.coefCount, 0);
+var energies =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.moCount, 0);
+var coefficients =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.moCount, /*org.eclipse.jdt.core.dom.SimpleName*/this.coefCount, 0);
 for (var i = 0; i < this.moCount; i++) {
 if (tokenPt == tokens.length) {
 tokens = JU.PT.getTokens(this.readLine());
@@ -354,7 +354,7 @@ var vibatom =  new JU.Lst();
 var ifreq = 0;
 var iatom = ac;
 var nValues = 3;
-var atomInfo =  Clazz.newFloatArray (3, 0);
+var atomInfo =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/3, 0);
 while (this.readLine() != null) {
 var tokens2 = JU.PT.getTokens(this.line);
 for (var i = 0; i < tokens2.length; i++) {
@@ -447,4 +447,4 @@ function(){
 return (this.line = this.r.rd());
 });
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v4 Sat Sep 14 10:37:53 CDT 2024
