@@ -69,4 +69,4 @@ if (!ignore[j]) this.asc.addVibrationVector(i + (lineBaseFreqCount + j) * ac, x,
 }
 });
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Sat Sep 14 10:37:53 CDT 2024
