@@ -121,10 +121,10 @@ var mat;
 var binaryCodes = this.rd();
 var tokens = JU.PT.getTokens(binaryCodes.trim());
 if (tokens.length < 16) return;
-var bytes =  Clazz.newByteArray (tokens.length, 0);
+var bytes =  Clazz.newByteArray (/*org.eclipse.jdt.core.dom.QualifiedName*/tokens.length, 0);
 for (var i = 0; i < tokens.length; i++) bytes[i] = JU.PT.parseIntRadix(tokens[i], 16);
 
-mat =  Clazz.newFloatArray (16, 0);
+mat =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/16, 0);
 for (var i = 16, j = bytes.length - 8; --i >= 0; j -= 8) mat[i] = JU.BC.bytesToDoubleToFloat(bytes, j, false);
 
 this.setTransform(mat[0], mat[1], mat[2], mat[4], mat[5], mat[6], mat[8], mat[9], mat[10]);
@@ -179,4 +179,4 @@ function(value){
 this.asc.setAtomSetName(this.constraints + (this.constraints.length == 0 ? "" : " ") + "Energy=" + value + " KJ");
 }, "~N");
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Sat Sep 14 10:37:53 CDT 2024
