@@ -56,7 +56,7 @@ var oy = this.parseFloatStr(tokens[1]);
 var oz = this.parseFloatStr(tokens[2]);
 tokens = JU.PT.getTokens(this.atts.get("griddatdata"));
 var pt = 1;
-var voxelData =  Clazz.newFloatArray (nPointsX, nPointsY, nPointsZ, 0);
+var voxelData =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/nPointsX, /*org.eclipse.jdt.core.dom.SimpleName*/nPointsY, /*org.eclipse.jdt.core.dom.SimpleName*/nPointsZ, 0);
 var sum = 0;
 for (var z = 0; z < nPointsZ; z++) for (var y = 0; y < nPointsY; y++) for (var x = 0; x < nPointsX; x++) {
 var f = this.parseFloatStr(tokens[pt++]);
@@ -102,4 +102,4 @@ return;
 }this.setKeepChars(false);
 }, "~S");
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
