@@ -569,4 +569,4 @@ bs.andNot(this.deleteAtoms);
 }});
 c$.unitCellParamTags =  Clazz.newArray(-1, ["a", "b", "c", "alpha", "beta", "gamma"]);
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
