@@ -46,11 +46,11 @@ if (tokens.length <= 2) this.nType = this.parseIntStr(tokens[1]);
 });
 Clazz.defineMethod(c$, "readTypesequence", 
 function(){
-this.fillFloatArray(this.line.substring(12), 0, this.typeArray =  Clazz.newFloatArray (this.nAtom, 0));
+this.fillFloatArray(this.line.substring(12), 0, this.typeArray =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.nAtom, 0));
 });
 Clazz.defineMethod(c$, "readAtomSpecies", 
 function(){
-this.znucl =  Clazz.newFloatArray (this.nType, 0);
+this.znucl =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.nType, 0);
 for (var i = 0; i < this.nType; i++) {
 this.discardLinesUntilContains("zion");
 var tokens = this.getTokens();
@@ -63,7 +63,7 @@ function(){
 Clazz.defineMethod(c$, "readIntiallattice", 
 function(){
 var f = 0;
-this.cellLattice =  Clazz.newFloatArray (9, 0);
+this.cellLattice =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/9, 0);
 for (var i = 0; i < 9; i++) {
 if (i % 3 == 0) {
 this.line = this.rd().substring(6);
@@ -97,11 +97,11 @@ this.setAtomCoordScaled(atom, this.getTokens(), 0, 0.5291772);
 this.rd();
 }
 this.discardLinesUntilContains("z");
-if (this.znucl == null) this.fillFloatArray(this.line.substring(12), 0, this.znucl =  Clazz.newFloatArray (this.nType, 0));
+if (this.znucl == null) this.fillFloatArray(this.line.substring(12), 0, this.znucl =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.nType, 0));
 var atoms = this.asc.atoms;
 for (var i = 0; i < this.nAtom; i++) atoms[i + i0].elementNumber = Clazz.floatToShort(this.znucl[Clazz.floatToInt(this.typeArray[i]) - 1]);
 
 this.applySymmetry();
 });
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
