@@ -79,7 +79,7 @@ this.setSpaceGroupName(this.line.substring(2));
 while (intTableNo < 0 && this.rdLine() != null) intTableNo = this.parseIntStr(this.line);
 
 this.setSpaceGroupName("" + intTableNo);
-}var data =  Clazz.newFloatArray (6, 0);
+}var data =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/6, 0);
 this.fillFloatArray(this.rdLine(), 0, data);
 for (var i = 0; i < 6; i++) this.setUnitCellItem(i, data[i]);
 
@@ -175,4 +175,4 @@ sb.append(this.line);
 return sb.toString();
 }, "~S");
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Tue Sep 10 13:37:06 CDT 2024
