@@ -1,5 +1,5 @@
 Clazz.declarePackage("J.adapter.readers.xtal");
-Clazz.load(["J.adapter.smarter.AtomSetCollectionReader"], "J.adapter.readers.xtal.CastepReader", ["JU.DF", "$.Lst", "$.M4", "$.P3", "$.PT", "$.V3", "J.adapter.smarter.Atom", "JU.Escape", "$.Logger", "$.Tensor"], function(){
+Clazz.load(["J.adapter.smarter.AtomSetCollectionReader"], "J.adapter.readers.xtal.CastepReader", ["JU.DF", "$.Lst", "$.M3", "$.M4", "$.P3", "$.PT", "$.V3", "J.adapter.smarter.Atom", "JS.SymmetryOperation", "JU.Logger", "$.SimpleUnitCell", "$.Tensor"], function(){
 var c$ = Clazz.decorateAsClass(function(){
 this.tokens = null;
 this.isPhonon = false;
@@ -24,6 +24,8 @@ this.chargeType = "MULL";
 this.isAllQ = false;
 this.haveCharges = false;
 this.tsType = null;
+this.allowSymmetryGeneration = true;
+this.lattTr = null;
 this.matSupercell = null;
 Clazz.instantialize(this, arguments);}, J.adapter.readers.xtal, "CastepReader", J.adapter.smarter.AtomSetCollectionReader);
 Clazz.prepareFields (c$, function(){
@@ -32,6 +34,7 @@ this.abc =  new Array(3);
 Clazz.overrideMethod(c$, "initializeReader", 
 function(){
 if (this.filter != null) {
+this.allowSymmetryGeneration = !this.checkFilterKey("NOSYM");
 this.chargeType = this.getFilter("CHARGE=");
 if (this.chargeType != null && this.chargeType.length > 4) this.chargeType = this.chargeType.substring(0, 4);
 this.filter = this.filter.$replace('(', '{').$replace(')', '}');
@@ -95,7 +98,8 @@ JU.Logger.info("Looking for q-pt=" + this.desiredQpt);
 }, "~S");
 Clazz.defineMethod(c$, "readFileData", 
 function(){
-while (this.tokenizeCastepCell() > 0) if (this.tokens.length >= 2 && this.tokens[0].equalsIgnoreCase("%BLOCK")) {
+while (this.tokenizeCastepCell() > 0) {
+if (this.tokens.length >= 2 && this.tokens[0].equalsIgnoreCase("%BLOCK")) {
 JU.Logger.info(this.line);
 if (this.tokens[1].equalsIgnoreCase("LATTICE_ABC")) {
 this.readLatticeAbc();
@@ -111,6 +115,11 @@ continue;
 this.setFractionalCoordinates(false);
 this.readPositionsAbs();
 continue;
+}if (this.tokens[1].equalsIgnoreCase("SYMMETRY_OPS")) {
+this.readSymmetryOps();
+continue;
+}} else if (this.allowSymmetryGeneration && this.tokens[0].equalsIgnoreCase("SYMMETRY_GENERATE")) {
+this.addJmolScript("print 'CastepReader SYMMETRY_GENERATE';modelkit spacegroup");
 }}
 if (this.isPhonon || this.isOutput || this.isTS) {
 if (this.isPhonon) {
@@ -119,6 +128,46 @@ this.asc.allowMultiple = false;
 }return true;
 }return false;
 });
+Clazz.defineMethod(c$, "readSymmetryOps", 
+function(){
+if (this.lattTr == null) {
+this.setLatticeVectors();
+var uc = this.getSymmetry().setUnitCellFromParams(this.unitCellParams, false, 0.0001);
+var vecs = uc.getUnitCellVectors();
+this.lattTr =  new JU.M3();
+this.lattTr.setColumnV(0, vecs[1]);
+this.lattTr.setColumnV(1, vecs[2]);
+this.lattTr.setColumnV(2, vecs[3]);
+}var lattTrInv = JU.M3.newM3(this.lattTr);
+lattTrInv.invert();
+var op =  new JU.M4();
+var nop = 0;
+this.tokenizeCastepCell();
+while (this.tokens.length > 0 && !this.tokens[0].equalsIgnoreCase("%ENDBLOCK")) {
+var op3 =  new JU.M3();
+var t =  new JU.P3();
+for (var i = 0; i < 4; i++) {
+if (this.tokens.length >= 3) {
+var x = this.parseCalcStr(this.tokens[0]);
+var y = this.parseCalcStr(this.tokens[1]);
+var z = this.parseCalcStr(this.tokens[2]);
+if (i < 3) {
+op3.setColumn3(i, x, y, z);
+} else {
+t.set(x, y, z);
+}} else {
+JU.Logger.warn("cannot read line with CASTEP symmetr_ops: " + this.line);
+}this.tokenizeCastepCell();
+}
+op3.mul2(op3, this.lattTr);
+op3.mul2(lattTrInv, op3);
+op.setMV(op3, t);
+var xyz = JS.SymmetryOperation.getXYZFromMatrix(op, false, true, false);
+nop++;
+JU.Logger.info("CASTEP reader op[" + nop + "] = " + xyz);
+this.setSymmetryOperator(xyz);
+}
+});
 Clazz.overrideMethod(c$, "checkLine", 
 function(){
 if (this.isOutput) {
@@ -231,7 +280,7 @@ function(){
 if (this.abc[0] == null) {
 this.setUnitCell(this.a, this.b, this.c, this.alpha, this.beta, this.gamma);
 return;
-}var lv =  Clazz.newFloatArray (3, 0);
+}var lv =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/3, 0);
 for (var i = 0; i < 3; i++) {
 lv[0] = this.abc[i].x;
 lv[1] = this.abc[i].y;
@@ -244,17 +293,17 @@ function(){
 if (this.tokenizeCastepCell() == 0) return;
 var factor = this.readLengthUnit(this.tokens[0]);
 if (this.tokens.length >= 3) {
-this.a = this.parseFloatStr(this.tokens[0]) * factor;
-this.b = this.parseFloatStr(this.tokens[1]) * factor;
-this.c = this.parseFloatStr(this.tokens[2]) * factor;
+this.a = this.parseCalcStr(this.tokens[0]) * factor;
+this.b = this.parseCalcStr(this.tokens[1]) * factor;
+this.c = this.parseCalcStr(this.tokens[2]) * factor;
 } else {
 JU.Logger.warn("error reading a,b,c in %BLOCK LATTICE_ABC in CASTEP .cell file");
 return;
 }if (this.tokenizeCastepCell() == 0) return;
 if (this.tokens.length >= 3) {
-this.alpha = this.parseFloatStr(this.tokens[0]);
-this.beta = this.parseFloatStr(this.tokens[1]);
-this.gamma = this.parseFloatStr(this.tokens[2]);
+this.alpha = this.parseCalcStr(this.tokens[0]);
+this.beta = this.parseCalcStr(this.tokens[1]);
+this.gamma = this.parseCalcStr(this.tokens[2]);
 } else {
 JU.Logger.warn("error reading alpha,beta,gamma in %BLOCK LATTICE_ABC in CASTEP .cell file");
 }});
@@ -265,12 +314,14 @@ var factor = this.readLengthUnit(this.tokens[0]);
 var x;
 var y;
 var z;
+this.lattTr =  new JU.M3();
 for (var i = 0; i < 3; i++) {
 if (this.tokens.length >= 3) {
-x = this.parseFloatStr(this.tokens[0]) * factor;
-y = this.parseFloatStr(this.tokens[1]) * factor;
-z = this.parseFloatStr(this.tokens[2]) * factor;
+x = this.parseCalcStr(this.tokens[0]) * factor;
+y = this.parseCalcStr(this.tokens[1]) * factor;
+z = this.parseCalcStr(this.tokens[2]) * factor;
 this.abc[i] = JU.V3.new3(x, y, z);
+this.lattTr.setColumnV(i, this.abc[i]);
 } else {
 JU.Logger.warn("error reading coordinates of lattice vector " + Integer.toString(i + 1) + " in %BLOCK LATTICE_CART in CASTEP .cell file");
 return;
@@ -283,6 +334,13 @@ this.alpha = (this.abc[1].angle(this.abc[2]) * 57.29577951308232);
 this.beta = (this.abc[2].angle(this.abc[0]) * 57.29577951308232);
 this.gamma = (this.abc[0].angle(this.abc[1]) * 57.29577951308232);
 });
+Clazz.defineMethod(c$, "parseCalcStr", 
+function(s){
+var f = JU.SimpleUnitCell.parseCalc(this.vwr, J.adapter.readers.xtal.CastepReader.functions, s);
+if (Float.isNaN(f)) {
+JU.Logger.error("CASTEP math error in " + s);
+}return f;
+}, "~S");
 Clazz.defineMethod(c$, "readPositionsFrac", 
 function(){
 if (this.tokenizeCastepCell() == 0) return;
@@ -315,7 +373,7 @@ atom.elementSymbol = this.tokens[0].substring(0, pt);
 atom.atomName = this.tokens[0];
 } else {
 atom.elementSymbol = this.tokens[0];
-}atom.set(this.parseFloatStr(this.tokens[1]), this.parseFloatStr(this.tokens[2]), this.parseFloatStr(this.tokens[3]));
+}atom.set(this.parseCalcStr(this.tokens[1]), this.parseCalcStr(this.tokens[2]), this.parseCalcStr(this.tokens[3]));
 atom.scale(factor);
 } else {
 JU.Logger.warn("cannot read line with CASTEP atom data: " + this.line);
@@ -360,13 +418,9 @@ return this.asc.getAtomIndex(this.tokens[0] + this.tokens[1]);
 });
 Clazz.defineMethod(c$, "getTensor", 
 function(atom, line0){
-var data =  Clazz.newFloatArray (9, 0);
-var a =  Clazz.newDoubleArray (3, 3, 0);
-this.fillFloatArray(line0, 0, data);
-JU.Logger.info("tensor " + atom.atomName + "\t" + JU.Escape.eAF(data));
-for (var p = 0, i = 0; i < 3; i++) for (var j = 0; j < 3; j++) a[i][j] = data[p++];
-
-
+line0 += this.rd() + this.rd();
+JU.Logger.info("tensor " + atom.atomName + " " + line0);
+var a = this.fill3x3(JU.PT.getTokens(line0), 0);
 atom.addTensor(( new JU.Tensor()).setFromAsymmetricTensor(a, "charge", atom.atomName + " " + line0), null, false);
 if (!this.haveCharges) this.appendLoadNote("Ellipsoids set \"charge\": Born Effective Charges");
 this.haveCharges = true;
@@ -379,7 +433,7 @@ this.readLines(2);
 var haveSpin = (this.line.indexOf("Spin") >= 0);
 this.rd();
 var atoms = this.asc.atoms;
-var spins = (haveSpin ?  Clazz.newFloatArray (atoms.length, 0) : null);
+var spins = (haveSpin ?  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.QualifiedName*/atoms.length, 0) : null);
 if (spins != null) for (var i = 0; i < spins.length; i++) spins[i] = 0;
 
 while (this.rd() != null && this.line.indexOf('=') < 0) {
@@ -462,7 +516,7 @@ freqs.addLast(Float.$valueOf(this.parseFloatStr(this.tokens[1])));
 }
 this.rd();
 var frequencyCount = freqs.size();
-var data =  Clazz.newFloatArray (8, 0);
+var data =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/8, 0);
 var t =  new JU.V3();
 this.asc.setCollectionName(qname);
 for (var i = 0; i < frequencyCount; i++) {
@@ -514,7 +568,8 @@ v.y = (cosph * data[4] - sinph * data[5]);
 v.z = (cosph * data[6] - sinph * data[7]);
 }v.scale(Math.sqrt(1 / atom.bfactor));
 }, "~A,J.adapter.smarter.Atom,JU.V3,JU.V3,JU.V3");
+c$.functions =  Clazz.newArray(-1, ["sqrt", "sin", "cos", "tan", "+", "-", "*", "/"]);
 c$.lengthUnitIds =  Clazz.newArray(-1, ["bohr", "m", "cm", "nm", "ang", "a0"]);
 c$.lengthUnitFactors =  Clazz.newFloatArray(-1, [0.5291772, 1E10, 1E8, 1E1, 1.0, 0.5291772]);
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Tue Sep 10 13:37:06 CDT 2024
