@@ -4,7 +4,7 @@ var c$ = Clazz.decorateAsClass(function(){
 this.buf = null;
 Clazz.instantialize(this, arguments);}, J.adapter.readers.xtal, "CmdfReader", J.adapter.smarter.AtomSetCollectionReader);
 Clazz.prepareFields (c$, function(){
-this.buf =  Clazz.newByteArray (100, 0);
+this.buf =  Clazz.newByteArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/100, 0);
 });
 Clazz.overrideMethod(c$, "initializeReader", 
 function(){
@@ -17,7 +17,7 @@ this.binaryDoc.seek(28);
 var len = this.binaryDoc.readInt();
 System.out.println("file length: " + len + " " + Integer.toHexString(len));
 this.seek("CELL", 32);
-var uc =  Clazz.newFloatArray (6, 0);
+var uc =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/6, 0);
 for (var i = 0; i < 6; i++) {
 uc[i] = this.binaryDoc.readFloat();
 }
@@ -118,4 +118,4 @@ if (ch1 >= 'a' && ch1 <= 'z') return sym.substring(0, 2);
 return "" + sym.charAt(0);
 }, "~S");
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
