@@ -37,8 +37,8 @@ Clazz.instantialize(this, arguments);}, J.adapter.readers.xtal, "CrystalReader",
 Clazz.prepareFields (c$, function(){
 this.ptOriginShift =  new JU.P3();
 this.symops =  new JU.Lst();
-this.f14 =  Clazz.newFloatArray (14, 0);
-this.f16 =  Clazz.newFloatArray (16, 0);
+this.f14 =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/14, 0);
+this.f16 =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/16, 0);
 });
 Clazz.defineMethod(c$, "rd", 
 function(){
@@ -239,7 +239,7 @@ m.put("ellipticity", Float.$valueOf(e1 / e2 - 1));
 m.put("anisotropy", Float.$valueOf(e3 - Math.abs(e1 + e2) / 2));
 } else if (key.equals("EIGENVECTORS")) {
 value = value + this.rd().substring(33) + this.rd().substring(33);
-var ev =  Clazz.newDoubleArray (3, 3, 0);
+var ev =  Clazz.newDoubleArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/3, /*org.eclipse.jdt.core.dom.NumberLiteral*/3, 0);
 for (var ei = 0, p = 0; ei < 3; ei++) {
 for (var ej = 0; ej < 3; ej++, p += 12) {
 ev[ej][ei] = this.parseFloatStr(value.substring(p, p + 12));
@@ -350,7 +350,7 @@ JU.Logger.info("oriented unit cell is in model " + this.asc.atomSetCount);
 });
 Clazz.defineMethod(c$, "readPrimitiveLatticeVectors", 
 function(){
-this.primitiveToCrystal = JU.M3.newA9(this.fillFloatArray(null, 0,  Clazz.newFloatArray (9, 0)));
+this.primitiveToCrystal = JU.M3.newA9(this.fillFloatArray(null, 0,  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/9, 0)));
 });
 Clazz.defineMethod(c$, "readHeader", 
 function(){
@@ -493,7 +493,7 @@ case 8:
 case 7:
 atomicNumber = this.getAtomicNumber(tokens[2]);
 offset = 4;
-if (i == 0) irreducible =  Clazz.newFloatArray (this.ac, 0);
+if (i == 0) irreducible =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.ac, 0);
 if (tokens[1].equals("T")) irreducible[i] = 1;
 break;
 default:
@@ -573,7 +573,7 @@ var data =  new JU.SB();
 while (this.rd() != null && this.line.indexOf("T") < 0) data.append(this.line);
 
 var tokens = JU.PT.getTokens(data.toString());
-var charges =  Clazz.newFloatArray (tokens.length, 0);
+var charges =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.QualifiedName*/tokens.length, 0);
 if (this.nuclearCharges == null || this.nuclearCharges.length != charges.length) this.nuclearCharges = charges;
 if (this.asc.ac == 0) return true;
 var atoms = this.asc.atoms;
@@ -590,7 +590,7 @@ Clazz.defineMethod(c$, "readFreqFragments",
 function(){
 var numAtomsFrag = this.parseIntRange(this.line, 39, 44);
 if (numAtomsFrag < 0) return;
-this.atomFrag =  Clazz.newIntArray (numAtomsFrag, 0);
+this.atomFrag =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/numAtomsFrag, 0);
 var Sfrag = "";
 while (this.rd() != null && this.line.indexOf("(") >= 0) Sfrag += this.line;
 
@@ -631,7 +631,7 @@ this.rd();
 var modelAtomCount = -1;
 while (this.rd() != null && this.line.startsWith(" FREQ(CM**-1)")) {
 var tokens = JU.PT.getTokens(this.line.substring(15));
-var frequencies =  Clazz.newFloatArray (tokens.length, 0);
+var frequencies =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.QualifiedName*/tokens.length, 0);
 var frequencyCount = frequencies.length;
 for (var i = 0; i < frequencyCount; i++) {
 frequencies[i] = this.parseFloatStr(tokens[i]);
@@ -756,7 +756,7 @@ return true;
 Clazz.defineMethod(c$, "readData", 
 function(name, nfields){
 this.processCoordLines();
-var f =  Clazz.newFloatArray (this.ac, 0);
+var f =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.ac, 0);
 for (var i = 0; i < this.ac; i++) f[i] = 0;
 
 var data = "";
@@ -809,4 +809,4 @@ return false;
 c$.crtypes =  Clazz.newArray(-1, ["??", "nuclei", "bonds", "rings", "cages"]);
 c$.smap =  Clazz.newIntArray(-1, [2, 3, 4, 11, 5, 6, 7, 12, 8, 9, 10, 13]);
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v4 Tue Sep 10 13:37:06 CDT 2024
