@@ -23,7 +23,7 @@ this.readFreq();
 });
 Clazz.defineMethod(c$, "readCellParam", 
 function(){
-this.unitCellData =  Clazz.newFloatArray (9, 0);
+this.unitCellData =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/9, 0);
 for (var n = 0, i = 0; n < 3; n++) {
 var tokens = JU.PT.getTokens(this.rd());
 this.unitCellData[i++] = this.parseFloatStr(!this.geomOpt ? tokens[0] : tokens[4]) * 0.5291772;
@@ -78,7 +78,7 @@ var ac = this.asc.getLastAtomSetAtomCount();
 while (this.rd() != null && this.line.charAt(1) == ' ') {
 var tokens = this.getTokens();
 var frequencyCount = Clazz.doubleToInt(tokens.length / 2);
-var frequencies =  Clazz.newFloatArray (frequencyCount, 0);
+var frequencies =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/frequencyCount, 0);
 for (var i = 1, n = 0; i < tokens.length; i += 2, n++) {
 frequencies[n] = this.parseFloatStr(tokens[i]);
 if (this.debugging) JU.Logger.debug((this.vibrationNumber + n) + " frequency=" + frequencies[n]);
@@ -100,4 +100,4 @@ this.readLines(2);
 }
 });
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
