@@ -39,7 +39,7 @@ function(andAPar){
 var i0 = (andAPar ? 0 : 3);
 if (this.line.contains("bohr")) this.aPar = 0.5291772;
 if (andAPar && this.line.contains("=")) this.aPar = this.parseFloatStr(this.line.substring(this.line.indexOf("=") + 1)) * 0.5291772;
-this.cellParams =  Clazz.newFloatArray (9, 0);
+this.cellParams =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/9, 0);
 for (var n = 0, i = 0; n < 3; n++) {
 var tokens = JU.PT.getTokens(this.rd());
 this.cellParams[i++] = this.parseFloatStr(tokens[i0]) * this.aPar;
@@ -99,4 +99,4 @@ this.asc.setInfo("Energy", this.totEnergy);
 this.asc.setAtomSetName("E = " + this.totEnergy + " Ry");
 });
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
