@@ -135,7 +135,7 @@ Clazz.defineMethod(c$, "readCellParameters",
 function(isLatticeVectors){
 if (isLatticeVectors) {
 this.rd();
-this.primitiveData = this.fillFloatArray(null, 0,  Clazz.newFloatArray (9, 0));
+this.primitiveData = this.fillFloatArray(null, 0,  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/9, 0));
 this.a = 0;
 return;
 }var i0 = (this.line.indexOf("Full cell") < 0 ? 0 : 4);
@@ -244,4 +244,4 @@ this.totEnergy = null;
 });
 c$.tags =  Clazz.newArray(-1, ["a", "b", "c", "alpha", "beta", "gamma"]);
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v4 Tue Sep 10 13:37:06 CDT 2024
