@@ -102,7 +102,7 @@ return true;
 Clazz.defineMethod(c$, "readCellParams", 
 function(){
 var tokens = this.getTokens();
-this.cellParams =  Clazz.newFloatArray (9, 0);
+this.cellParams =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/9, 0);
 for (var i = 0; i < 9; i++) this.cellParams[i] = this.parseFloatStr(tokens[i + 1]);
 
 this.addExplicitLatticeVector(0, this.cellParams, 0);
@@ -144,7 +144,7 @@ return true;
 }var isIsc = type.startsWith("isc");
 if (tokens.length == 10) {
 this.magresUnits.remove(type);
-var data =  Clazz.newFloatArray (9, 0);
+var data =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/9, 0);
 for (var i = 0; i < 9; ) data[i] = this.parseFloatStr(tokens[++i]);
 
 JU.Logger.info("Magres reader creating magres_" + type + ": " + JU.Escape.eAF(data));
@@ -157,7 +157,7 @@ JU.Logger.warn(type + " ignored; atom1 == atom2 for " + atomName1 + " line: " +
 return true;
 }var id = atomName1;
 if (atomName2 != null) id += "//" + atomName2;
-var a =  Clazz.newDoubleArray (3, 3, 0);
+var a =  Clazz.newDoubleArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/3, /*org.eclipse.jdt.core.dom.NumberLiteral*/3, 0);
 for (var i = 0; i < 3; i++) for (var j = 0; j < 3; j++) a[i][j] = Double.$valueOf(tokens[pt++]).doubleValue();
 
 
@@ -175,4 +175,4 @@ this.interactionTensors.addLast(t);
 return true;
 });
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
