@@ -45,7 +45,7 @@ function(){
 });
 Clazz.defineMethod(c$, "readUnitCell", 
 function(){
-var unitCellData =  Clazz.newFloatArray (3, 0);
+var unitCellData =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/3, 0);
 this.addExplicitLatticeVector(0, this.fillFloatArray(this.getLine(), 0, unitCellData), 0);
 this.addExplicitLatticeVector(1, this.fillFloatArray(this.getLine(), 0, unitCellData), 0);
 this.addExplicitLatticeVector(2, this.fillFloatArray(this.getLine(), 0, unitCellData), 0);
@@ -62,9 +62,9 @@ this.addAtomXYZSymName(tokens, 1, J.adapter.smarter.AtomSetCollectionReader.getE
 haveConstraints = (tokens.length >= 7) && haveConstraints;
 if (haveConstraints) constraints.addLast( Clazz.newFloatArray(-1, [Float.parseFloat(tokens[4]), Float.parseFloat(tokens[5]), Float.parseFloat(tokens[6])]));
 }
-var cx =  Clazz.newFloatArray (this.nAtoms, 0);
-var cy =  Clazz.newFloatArray (this.nAtoms, 0);
-var cz =  Clazz.newFloatArray (this.nAtoms, 0);
+var cx =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.nAtoms, 0);
+var cy =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.nAtoms, 0);
+var cz =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.nAtoms, 0);
 var c =  Clazz.newFloatArray(-1, [1, 1, 1]);
 for (i = this.nAtoms; --i >= 0; ) {
 if (haveConstraints) c = constraints.get(i);
@@ -118,7 +118,7 @@ data.put(name, lines);
 } else {
 name = "pwm_" + name;
 if (values == null) {
-values =  Clazz.newFloatArray (this.nAtoms, 0);
+values =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.nAtoms, 0);
 } else {
 this.getLine();
 }var n = 0;
@@ -139,9 +139,9 @@ this.appendLoadNote("PWmatReader read property_" + name);
 Clazz.defineMethod(c$, "readVectors", 
 function(name, offset, haveLine){
 if (!haveLine) this.getLine();
-var valuesX =  Clazz.newFloatArray (this.nAtoms, 0);
-var valuesY =  Clazz.newFloatArray (this.nAtoms, 0);
-var valuesZ =  Clazz.newFloatArray (this.nAtoms, 0);
+var valuesX =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.nAtoms, 0);
+var valuesY =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.nAtoms, 0);
+var valuesZ =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.nAtoms, 0);
 var n = 0;
 for (var i = 0; ; ) {
 var tokens = this.getTokens();
@@ -189,7 +189,7 @@ var p = this.asc.getAtomSetAuxiliaryInfoValue(this.asc.iSet, "atomProperties");
 if (p != null) {
 var atoms = this.asc.atoms;
 var n = (this.asc.bsAtoms == null ? this.nAtoms : this.asc.bsAtoms.cardinality());
-var map = (n == this.nAtoms ? null :  Clazz.newIntArray (this.nAtoms, 0));
+var map = (n == this.nAtoms ? null :  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.nAtoms, 0));
 if (map != null) {
 for (var j = 0, k = 0; j < this.nAtoms; j++) {
 if (this.asc.bsAtoms.get(j)) map[j] = k++;
@@ -198,7 +198,7 @@ if (this.asc.bsAtoms.get(j)) map[j] = k++;
 var key = e.getKey();
 if (key.startsWith("pwm_")) {
 var af = e.getValue();
-var af2 =  Clazz.newFloatArray (n, 0);
+var af2 =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/n, 0);
 for (var j = 0; j < this.nAtoms; j++) {
 af2[map == null ? j : map[j]] = af[atoms[j].atomSite];
 }
@@ -208,7 +208,7 @@ e.setValue(af2);
 Clazz.overrideMethod(c$, "finalizeSubclassReader", 
 function(){
 if (!this.haveMagnetic && this.asc.ac > 0) {
-this.setProperties("pwm_magnetic",  Clazz.newFloatArray (this.asc.ac, 0), this.nAtoms);
+this.setProperties("pwm_magnetic",  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.QualifiedName*/this.asc.ac, 0), this.nAtoms);
 }});
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
