@@ -5,7 +5,7 @@ this.sfacElementSymbols = null;
 this.isCmdf = false;
 this.tokens = null;
 this.altloc = '\0';
-this.negDisorder = false;
+this.part = 0;
 this.isCentroSymmetric = false;
 this.haveXYZ = false;
 Clazz.instantialize(this, arguments);}, J.adapter.readers.xtal, "ShelxReader", J.adapter.smarter.AtomSetCollectionReader);
@@ -16,10 +16,10 @@ this.setFractionalCoordinates(true);
 Clazz.overrideMethod(c$, "checkLine", 
 function(){
 var lineLength;
-while ((lineLength = (this.line = this.line.trim()).length) > 0 && this.line.charAt(lineLength - 1) == '=') this.line = this.line.substring(0, lineLength - 1) + this.rd();
+if (this.line.length == 0 || this.line.startsWith(" ")) return true;
+while ((lineLength = this.line.length) > 0 && this.line.charAt(lineLength - 1) == '=') this.line = this.line.substring(0, lineLength - 1) + this.rd();
 
 this.tokens = this.getTokens();
-if (this.tokens.length == 0) return true;
 var command = this.tokens[0].toUpperCase();
 if (command.equals("TITL")) {
 if (!this.doGetModel(++this.modelNumber, null)) return this.checkLastModel();
@@ -76,9 +76,8 @@ break;
 }, "~N");
 Clazz.defineMethod(c$, "processPartRecord", 
 function(){
-var part = this.parseIntStr(this.tokens[1]);
-this.altloc = String.fromCharCode(part == 0 ? 0 : 48 + Math.abs(part));
-if (part < 0) this.negDisorder = true;
+this.part = this.parseIntStr(this.tokens[1]);
+this.altloc = String.fromCharCode(this.part == 0 ? 0 : 48 + Math.abs(this.part));
 });
 Clazz.defineMethod(c$, "parseLattRecord", 
 function(){
@@ -151,6 +150,7 @@ var elementIndex = -1;
 var atomName = null;
 try {
 atomName = this.tokens[0];
+elementIndex = this.parseIntStr(this.tokens[1]) - 1;
 x = this.parsePrecision(this.tokens[2]) % 10;
 y = this.parsePrecision(this.tokens[3]) % 10;
 z = this.parsePrecision(this.tokens[4]) % 10;
@@ -174,9 +174,9 @@ atom.elementSymbol = "Xx";
 atom.elementSymbol = this.sfacElementSymbols[elementIndex];
 }this.setAtomCoordXYZ(atom, x, y, z);
 atom.altLoc = this.altloc;
-atom.isNegDisorder = this.negDisorder;
+atom.part = this.part;
 if (this.tokens.length == 12) {
-var data =  Clazz.newFloatArray (8, 0);
+var data =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/8, 0);
 data[0] = this.parseFloatStr(this.tokens[6]);
 data[1] = this.parseFloatStr(this.tokens[7]);
 data[2] = this.parseFloatStr(this.tokens[8]);
@@ -226,6 +226,11 @@ this.isCentroSymmetric = false;
 this.haveXYZ = false;
 }this.applySymTrajASCR();
 });
+Clazz.overrideMethod(c$, "finalizeSubclassReader", 
+function(){
+Clazz.superCall(this, J.adapter.readers.xtal.ShelxReader, "finalizeReaderASCR", []);
+this.asc.xtalSymmetry.setPartProperty();
+});
 c$.supportedRecordTypes =  Clazz.newArray(-1, ["TITL", "CELL", "SPGR", "SFAC", "LATT", "SYMM", "NOTE", "ATOM", "PART", "END"]);
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
