@@ -132,14 +132,14 @@ this.discardLinesUntilContains("%endblock AtomicCoordinatesAndAtomicSpecies");
 Clazz.defineMethod(c$, "setCell", 
 function(key){
 if (key.equals("latticevectors")) {
-this.unitCellVectors =  Clazz.newFloatArray (9, 0);
+this.unitCellVectors =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/9, 0);
 this.fillFloatArray(null, 0, this.unitCellVectors);
 } else if (key.equals("latticeconstant")) {
 var tokens = this.getTokens();
 this.latticeConstant = this.parseFloatStr(tokens[1]);
 this.latticeUnits = tokens[2].toLowerCase();
 } else if (key.equals("latticeparameters")) {
-this.unitCellParamsS =  Clazz.newFloatArray (6, 0);
+this.unitCellParamsS =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/6, 0);
 this.fillFloatArray(this.line.substring(this.line.indexOf("ters") + 4), 0, this.unitCellParamsS);
 }return true;
 }, "~S");
@@ -203,4 +203,4 @@ this.asc.setInfo("Energy", energy);
 this.asc.setAtomSetName("Energy = " + energy + " eV");
 });
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
