@@ -70,7 +70,7 @@ this.elementNames.addLast(name);
 });
 Clazz.defineMethod(c$, "readAtomCountAndSetNames", 
 function(){
-var numofElement =  Clazz.newIntArray (100, 0);
+var numofElement =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/100, 0);
 var tokens = JU.PT.getTokens(this.line.substring(this.line.indexOf("=") + 1));
 this.ac = 0;
 for (var i = 0; i < tokens.length; i++) this.ac += (numofElement[i] = this.parseIntStr(tokens[i]));
@@ -87,7 +87,7 @@ if (this.asc.ac > 0) {
 this.setSymmetry();
 this.asc.newAtomSet();
 this.setAtomSetInfo();
-}var f =  Clazz.newFloatArray (3, 0);
+}var f =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/3, 0);
 for (var i = 0; i < 3; i++) this.addExplicitLatticeVector(i, this.fillFloatArray(this.fixMinus(this.rd()), 0, f), 0);
 
 });
@@ -185,4 +185,4 @@ this.rd();
 }
 });
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
