@@ -580,7 +580,7 @@ Clazz.defineMethod(c$, "setSymmetryOperator",
 function(xyz){
 if (this.ignoreFileSymmetryOperators) return -1;
 var isym = this.asc.getXSymmetry().addSpaceGroupOperation(xyz, true);
-if (isym < 0) JU.Logger.warn("Skippings symmetry operation " + xyz);
+if (isym < 0) JU.Logger.warn("Skipping symmetry operation " + xyz);
 this.iHaveSymmetryOperators = true;
 return isym;
 }, "~S");
@@ -1322,4 +1322,4 @@ function(pt, prec){
 if (this.floatifyJavaDouble) JU.PT.fixPtFloats(pt, prec);
 }, "JU.P3,~N");
 });
-;//5.0.1-v4 Thu Aug 15 08:54:39 CDT 2024
+;//5.0.1-v4 Thu Sep 12 20:50:17 CDT 2024
