@@ -21,4 +21,4 @@ function(){
 return "[Bond " + this.atomIndex1 + " " + this.atomIndex2 + " " + this.order + "]";
 });
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
