@@ -17,7 +17,7 @@ this.modelStartEnd = null;
 this.bsAll = null;
 Clazz.instantialize(this, arguments);}, J.adapter.smarter, "Structure", null, Cloneable);
 Clazz.prepareFields (c$, function(){
-this.atomStartEnd =  Clazz.newIntArray (2, 0);
+this.atomStartEnd =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/2, 0);
 this.modelStartEnd =  Clazz.newIntArray(-1, [-1, -1]);
 });
 Clazz.makeConstructor(c$, 
@@ -71,4 +71,4 @@ throw e;
 return s;
 });
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
