@@ -67,7 +67,7 @@ this.mident =  new JU.M4();
 this.mident.setIdentity();
 }this.acr.lstNCS = null;
 this.setLatticeCells();
-var lc = (this.latticeCells != null && this.latticeCells[0] != 0 ?  Clazz.newIntArray (3, 0) : null);
+var lc = (this.latticeCells != null && this.latticeCells[0] != 0 ?  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/3, 0) : null);
 if (lc != null) for (var i = 0; i < 3; i++) lc[i] = this.latticeCells[i];
 
 this.latticeCells = null;
@@ -148,7 +148,7 @@ var chainID = atoms[iAtom].chainID;
 if (chainID > maxChain) maxChain = chainID;
 }
 var bsAtoms = this.asc.bsAtoms;
-var atomMap = (addBonds ?  Clazz.newIntArray (this.asc.ac, 0) : null);
+var atomMap = (addBonds ?  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.QualifiedName*/this.asc.ac, 0) : null);
 for (var imt = (biomtchains == null ? 1 : 0); imt < len; imt++) {
 if (filter.indexOf("!#") >= 0) {
 if (filter.indexOf("!#" + (imt + 1) + ";") >= 0) continue;
@@ -447,7 +447,7 @@ this.checkNearAtoms = this.acr.checkNearAtoms || excludedOps != null;
 JU.SimpleUnitCell.setMinMaxLatticeParameters(this.ndims, this.minXYZ, this.maxXYZ, 0);
 this.latticeOp = this.symmetry.getLatticeOp();
 this.crystalReaderLatticeOpsOnly = (this.asc.crystalReaderLatticeOpsOnly && this.latticeOp >= 0);
-if (this.doCentroidUnitCell) this.asc.setInfo("centroidMinMax",  Clazz.newIntArray(-1, [this.minXYZ.x, this.minXYZ.y, this.minXYZ.z, this.maxXYZ.x, this.maxXYZ.y, this.maxXYZ.z, (this.centroidPacked ? 1 : 0)]));
+if (this.doCentroidUnitCell) this.asc.setInfo("centroidMinMax",  Clazz.newIntArray(-1, [this.minXYZ.x, this.minXYZ.y, this.minXYZ.z, this.maxXYZ.x, this.maxXYZ.y, this.maxXYZ.z, (this.centroidPacked ? Clazz.floatToInt(this.packingRange * 100) : 0)]));
 if (this.doCentroidUnitCell || this.acr.doPackUnitCell || this.symmetryRange != 0 && this.maxXYZ.x - this.minXYZ.x == 1 && this.maxXYZ.y - this.minXYZ.y == 1 && this.maxXYZ.z - this.minXYZ.z == 1) {
 this.minXYZ0 = JU.P3.new3(this.minXYZ.x, this.minXYZ.y, this.minXYZ.z);
 this.maxXYZ0 = JU.P3.new3(this.maxXYZ.x, this.maxXYZ.y, this.maxXYZ.z);
@@ -510,8 +510,8 @@ var op = sym.getSpaceGroupOperation(0);
 if (this.doPackUnitCell) {
 pttemp =  new JU.P3();
 this.ptOffset.set(0, 0, 0);
-}var atomMap = (this.bondCount0 > this.asc.bondIndex0 && this.applySymmetryToBonds ?  Clazz.newIntArray (n, 0) : null);
-var unitCells =  Clazz.newIntArray (nCells, 0);
+}var atomMap = (this.bondCount0 > this.asc.bondIndex0 && this.applySymmetryToBonds ?  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/n, 0) : null);
+var unitCells =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/nCells, 0);
 for (var tx = this.minXYZ.x; tx < this.maxXYZ.x; tx++) {
 for (var ty = this.minXYZ.y; ty < this.maxXYZ.y; ty++) {
 for (var tz = this.minXYZ.z; tz < this.maxXYZ.z; tz++) {
@@ -726,7 +726,7 @@ for (var i = nTimes; --i >= 0; ) s.append(data);
 p.put(key, s.toString());
 } else {
 var f = val;
-var fnew =  Clazz.newFloatArray (f.length * nTimes, 0);
+var fnew =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.InfixExpression*/f.length * nTimes, 0);
 for (var i = nTimes; --i >= 0; ) System.arraycopy(f, 0, fnew, i * f.length, f.length);
 
 }}
@@ -736,7 +736,7 @@ function(symmetry){
 var name = this.asc.getAtomSetAuxiliaryInfoValue(-1, "spaceGroup");
 symmetry.setFinalOperations(this.ndims, name, this.asc.atoms, this.firstAtom, this.noSymmetryCount, this.doNormalize, this.filterSymop);
 if (this.filterSymop != null || name == null || name.equals("unspecified!")) {
-this.setAtomSetSpaceGroupName(symmetry.getSpaceGroupName());
+this.setAtomSetSpaceGroupName(symmetry.getUnitCellDisplayName());
 }if (this.unitCellParams != null || Float.isNaN(this.acr.unitCellParams[0])) return;
 if (symmetry.fixUnitCell(this.acr.unitCellParams)) {
 this.acr.appendLoadNote("Unit cell parameters were adjusted to match space group!");
@@ -755,7 +755,9 @@ this.asc.setGlobalBoolean(1);
 Clazz.defineMethod(c$, "setAtomSetSpaceGroupName", 
 function(spaceGroupName){
 this.symmetry.setSpaceGroupName(spaceGroupName);
-this.asc.setCurrentModelInfo("spaceGroup", spaceGroupName + "");
+var s = spaceGroupName + "";
+this.asc.setCurrentModelInfo("f2cTitle", s);
+this.asc.setCurrentModelInfo("spaceGroup", s);
 }, "~S");
 Clazz.defineMethod(c$, "setCurrentModelInfo", 
 function(n, sym, unitCells){
@@ -771,11 +773,8 @@ if (this.acr.isSUPERCELL) this.asc.setCurrentModelInfo("supercell", this.acr.str
 }this.asc.setCurrentModelInfo("presymmetryAtomIndex", Integer.$valueOf(this.firstAtom));
 var operationCount = this.symmetry.getSpaceGroupOperationCount();
 if (operationCount > 0) {
-var symmetryList =  new Array(operationCount);
-for (var i = 0; i < operationCount; i++) symmetryList[i] = "" + this.symmetry.getSpaceGroupXyz(i, this.doNormalize);
-
-this.asc.setCurrentModelInfo("symmetryOperations", symmetryList);
-this.asc.setCurrentModelInfo("symmetryOps", this.symmetry.getSymmetryOperations());
+this.asc.setCurrentModelInfo("symmetryOperations", this.symmetry.getSymopList(this.doNormalize));
+this.asc.setCurrentModelInfo("symOpsTemp", this.symmetry.getSymmetryOperations());
 }this.asc.setCurrentModelInfo("symmetryCount", Integer.$valueOf(operationCount));
 this.asc.setCurrentModelInfo("latticeType", this.acr.latticeType == null ? "P" : this.acr.latticeType);
 this.asc.setCurrentModelInfo("intlTableNo", this.symmetry.getIntTableNumber());
@@ -849,7 +848,7 @@ if (this.rmaxz < c.z) this.rmaxz = c.z;
 }, "JU.P3");
 Clazz.defineMethod(c$, "setUnitCell", 
 function(info, matUnitCellOrientation, unitCellOffset){
-this.unitCellParams =  Clazz.newFloatArray (info.length, 0);
+this.unitCellParams =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.QualifiedName*/info.length, 0);
 for (var i = 0; i < info.length; i++) this.unitCellParams[i] = info[i];
 
 this.asc.haveUnitCell = true;
@@ -1021,7 +1020,7 @@ return pt;
 Clazz.defineMethod(c$, "setPartProperty", 
 function(){
 for (var iset = this.asc.atomSetCount; --iset >= 0; ) {
-var parts =  Clazz.newFloatArray (this.asc.getAtomSetAtomCount(iset), 0);
+var parts =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.MethodInvocation*/this.asc.getAtomSetAtomCount(iset), 0);
 for (var i = 0, ia = this.asc.getAtomSetAtomIndex(iset), n = parts.length; i < n; i++) {
 var a = this.asc.atoms[ia++];
 parts[i] = a.part;
@@ -1097,7 +1096,7 @@ function(code, rs, vs, sigma){
 this.spaceGroup.isSSG = true;
 var s = JS.SymmetryOperation.getXYZFromRsVs(rs, vs, false);
 var i = this.spaceGroup.addSymmetry(s, -1, true);
-this.spaceGroup.operations[i].setSigma(code, sigma);
+this.spaceGroup.matrixOperations[i].setSigma(code, sigma);
 return s;
 }, "~S,JU.Matrix,JU.Matrix,JU.Matrix");
 Clazz.defineMethod(c$, "checkDistance", 
@@ -1120,7 +1119,7 @@ JS.SymmetryOperation.getMatrixFromString(null, xyz, rotTransMatrix, false, true,
 }, "~S,~A");
 Clazz.defineMethod(c$, "getSpaceGroupOperationCode", 
 function(iOp){
-return this.spaceGroup.operations[iOp].subsystemCode;
+return this.spaceGroup.matrixOperations[iOp].subsystemCode;
 }, "~N");
 Clazz.defineMethod(c$, "getTensor", 
 function(vwr, parBorU){
@@ -1163,7 +1162,7 @@ return this.unitCell.getF2C();
 });
 Clazz.defineMethod(c$, "addInversion", 
 function(){
-var ops = this.spaceGroup.operations;
+var ops = this.spaceGroup.matrixOperations;
 var inv =  new JU.M4();
 inv.m00 = inv.m11 = inv.m22 = -1;
 inv.m33 = 1;
@@ -1177,4 +1176,4 @@ this.addSpaceGroupOperation(s, 0);
 });
 /*eoif3*/})();
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Thu Sep 12 21:06:25 CDT 2024
