@@ -116,7 +116,7 @@ var jmol_atom =  new JU.SB();
 jmol_atom.append("\n\nloop_\n_jmol_atom_index\n_jmol_atom_name\n_jmol_atom_site_label\n");
 var nAtoms = 0;
 var p =  new JU.P3();
-var elemNums =  Clazz.newIntArray (130, 0);
+var elemNums =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/130, 0);
 for (var pi = 0, i = bsOut.nextSetBit(0); i >= 0; i = bsOut.nextSetBit(i + 1)) {
 var a = atoms[i];
 p.setT(a);
@@ -229,4 +229,4 @@ return (this.oc == null ? "" : this.oc.toString());
 });
 c$.fset0 = JU.P3.new3(555, 555, 1);
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Tue Sep 10 11:29:28 CDT 2024
