@@ -28,4 +28,4 @@ function(vwr, state){
 return J.api.Interface.getInterface("JS.Symmetry", vwr, state);
 }, "JV.Viewer,~S");
 });
-;//5.0.1-v4 Thu Aug 15 08:54:39 CDT 2024
+;//5.0.1-v4 Tue Sep 10 11:29:28 CDT 2024
