@@ -1,3 +1,3 @@
 Clazz.declarePackage("J.api");
 Clazz.declareInterface(J.api, "JmolModulationSet");
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Tue Sep 10 11:29:28 CDT 2024
