@@ -2,4 +2,4 @@ Clazz.declarePackage("J.api");
 (function(){
 var c$ = Clazz.declareInterface(J.api, "JmolScriptManager");
 })();
-;//5.0.1-v4 Thu Aug 15 08:54:39 CDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
