@@ -1,3 +1,3 @@
 Clazz.declarePackage("J.api.js");
 Clazz.declareInterface(J.api.js, "JmolToJSmolInterface", javajs.api.js.J2SObjectInterface);
-;//5.0.1-v4 Thu Aug 15 08:54:39 CDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
