@@ -2,4 +2,4 @@ Clazz.declarePackage("J.awtjs");
 (function(){
 var c$ = Clazz.declareType(J.awtjs, "Event", null);
 })();
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
