@@ -36,4 +36,4 @@ context.font = font.font;
 return Math.ceil(context.measureText(text).width);
 }}, "JU.Font,~O,~S");
 })();
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
