@@ -10,7 +10,7 @@ Clazz.makeConstructor(c$,
 function(a, b, htLadders){
 this.a = a;
 this.b = b;
-this.ladder =  Clazz.newIntArray (2, 2, 0);
+this.ladder =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/2, /*org.eclipse.jdt.core.dom.NumberLiteral*/2, 0);
 this.ladder[0][0] = this.ladder[0][1] = Math.min(a.i, b.i);
 this.ladder[1][0] = this.ladder[1][1] = Math.max(a.i, b.i);
 this.addLadder(htLadders);
@@ -48,4 +48,4 @@ function(){
 return (this.isAntiparallel ? "a " : "p ") + this.a + " - " + this.b + "\t" + JU.Escape.e(this.ladder);
 });
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
