@@ -84,4 +84,4 @@ if (inSide) for (var i = 0; i < n; i++) normals[i].scale(-1);
 return JU.MeshSurface.newMesh(false, vertexes, 0, faces, normals, 0);
 }, "~B");
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
