@@ -242,4 +242,4 @@ if (!this.haveMacros) this.writeMacros2();
 this.output("r(" + this.getTriad(ptA) + "," + this.getTriad(ptB) + "," + this.getTriad(ptC) + "," + this.color4(colix) + ")\n");
 }, "JU.T3,JU.T3,JU.T3,~N");
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
