@@ -224,4 +224,4 @@ this.output(" V2 " + this.triad(ptC));
 this.outputTextureCode();
 }, "JU.T3,JU.T3,JU.T3,~N");
 });
-;//5.0.1-v4 Thu Aug 15 08:54:39 CDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
