@@ -228,4 +228,4 @@ Clazz.overrideMethod(c$, "plotText",
 function(x, y, z, colix, text, font3d){
 }, "~N,~N,~N,~N,~S,JU.Font");
 });
-;//5.0.1-v4 Thu Aug 15 08:54:39 CDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
