@@ -328,4 +328,4 @@ this.gdata.plotText(x, y, z, this.gdata.getColorArgbOrGray(colix), 0, text, font
 this.outputComment("end text " + this.nText + ": " + text);
 }, "~N,~N,~N,~N,~S,JU.Font");
 });
-;//5.0.1-v4 Thu Aug 15 08:54:39 CDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
