@@ -51,8 +51,8 @@ this.yTip = 0;
 this.zTip = 0;
 Clazz.instantialize(this, arguments);}, J.g3d, "CylinderRenderer", null);
 Clazz.prepareFields (c$, function(){
-this.xyztRaster =  Clazz.newArray(-1, [ Clazz.newFloatArray (32, 0),  Clazz.newFloatArray (32, 0),  Clazz.newFloatArray (32, 0),  Clazz.newFloatArray (32, 0)]);
-this.xyzfRaster =  Clazz.newArray(-1, [ Clazz.newIntArray (32, 0),  Clazz.newIntArray (32, 0),  Clazz.newIntArray (32, 0),  Clazz.newIntArray (32, 0)]);
+this.xyztRaster =  Clazz.newArray(-1, [ Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/32, 0),  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/32, 0),  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/32, 0),  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/32, 0)]);
+this.xyzfRaster =  Clazz.newArray(-1, [ Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/32, 0),  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/32, 0),  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/32, 0),  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/32, 0)]);
 this.ptA0i =  new JU.P3i();
 this.ptB0i =  new JU.P3i();
 });
@@ -600,4 +600,4 @@ this.argbEndcap = shadesEndcap[this.endcapShadeIndex];
 this.endCapHidden = (this.endcaps == 1);
 }, "~B,~B");
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
