@@ -1,3 +1,3 @@
 Clazz.declarePackage("J.g3d");
 Clazz.declareInterface(J.g3d, "G3DRenderer");
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
