@@ -27,8 +27,8 @@ Clazz.instantialize(this, arguments);}, J.g3d, "HermiteRenderer", null, J.g3d.G3
 Clazz.prepareFields (c$, function(){
 this.pLeft =  new Array(16);
 this.pRight =  new Array(16);
-this.sLeft =  Clazz.newFloatArray (16, 0);
-this.sRight =  Clazz.newFloatArray (16, 0);
+this.sLeft =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/16, 0);
+this.sRight =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/16, 0);
 this.pTopLeft =  new Array(16);
 this.pTopRight =  new Array(16);
 this.pBotLeft =  new Array(16);
@@ -361,4 +361,4 @@ for (var top = 0; top < numTopStrandPoints && (top + numTopStrandPoints) < size;
 c$.vAB =  new JU.V3();
 c$.vAC =  new JU.V3();
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
