@@ -12,4 +12,4 @@ function(offset, z, p){
 if ((offset % this.width) % 2 == (Clazz.doubleToInt(offset / this.width)) % 2) this.p0.addPixel(offset, z, p);
 }, "~N,~N,~N");
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
