@@ -10,7 +10,7 @@ Clazz.instantialize(this, arguments);}, J.g3d, "PixelatorShaded", J.g3d.Pixelato
 Clazz.makeConstructor(c$, 
 function(g){
 Clazz.superConstructor(this, J.g3d.PixelatorShaded, [g]);
-this.tmp =  Clazz.newIntArray (3, 0);
+this.tmp =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/3, 0);
 }, "J.g3d.Graphics3D");
 Clazz.defineMethod(c$, "set", 
 function(zSlab, zDepth, zShadePower){
@@ -48,4 +48,4 @@ this.p0.pb[i] = 0xFF000000 | z | (z << 8) | (z << 16);
 }
 });
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
