@@ -30,8 +30,8 @@ return this.apiPlatform.getGraphics(this.allocateOffscreenImage(1, 1));
 Clazz.defineMethod(c$, "allocateTBuffers", 
 function(antialiasTranslucent){
 this.bufferSizeT = (antialiasTranslucent ? this.bufferSize : this.windowSize);
-this.zBufferT =  Clazz.newIntArray (this.bufferSizeT, 0);
-this.pBufferT =  Clazz.newIntArray (this.bufferSizeT, 0);
+this.zBufferT =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.bufferSizeT, 0);
+this.pBufferT =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.bufferSizeT, 0);
 }, "~B");
 Clazz.defineMethod(c$, "allocateBuffers", 
 function(width, height, antialias, isImageWrite){
@@ -44,8 +44,8 @@ height *= 2;
 }this.bufferWidth = width;
 this.bufferHeight = height;
 this.bufferSize = this.bufferWidth * this.bufferHeight;
-this.zBuffer =  Clazz.newIntArray (this.bufferSize, 0);
-this.pBuffer =  Clazz.newIntArray (this.bufferSize, 0);
+this.zBuffer =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.bufferSize, 0);
+this.pBuffer =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.bufferSize, 0);
 this.bufferedImage = this.apiPlatform.allocateRgbImage(this.windowWidth, this.windowHeight, this.pBuffer, this.windowSize, J.g3d.Platform3D.backgroundTransparent, isImageWrite);
 }, "~N,~N,~B,~B");
 Clazz.defineMethod(c$, "releaseBuffers", 
@@ -118,4 +118,4 @@ J.g3d.Platform3D.backgroundTransparent = tf;
 }, "~B");
 c$.backgroundTransparent = false;
 })();
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
