@@ -20,10 +20,10 @@ this.planeShades = null;
 this.dxyz = null;
 Clazz.instantialize(this, arguments);}, J.g3d, "SphereRenderer", null);
 Clazz.prepareFields (c$, function(){
-this.zroot =  Clazz.newDoubleArray (2, 0);
+this.zroot =  Clazz.newDoubleArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/2, 0);
 this.ptTemp =  new JU.P3();
-this.planeShades =  Clazz.newIntArray (3, 0);
-this.dxyz =  Clazz.newFloatArray (3, 3, 0);
+this.planeShades =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/3, 0);
+this.dxyz =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/3, /*org.eclipse.jdt.core.dom.NumberLiteral*/3, 0);
 });
 Clazz.makeConstructor(c$, 
 function(g3d){
@@ -94,7 +94,7 @@ var z2 = radiusF2 - y2 - x2;
 if (z2 >= 0) ++countSE;
 }
 }
-ss =  Clazz.newIntArray (countSE, 0);
+ss =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/countSE, 0);
 var offset = 0;
 ys = d ? 0 : 0.5;
 for (var i = 0; i < radius; ++i, ++ys) {
@@ -389,4 +389,4 @@ randu = ((randu + xC + yC) | 1) & 0x7FFFFFFF;
 }
 }, "~N,~N,~N,~N,~N,~N,~A");
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
