@@ -125,7 +125,7 @@ Clazz.defineMethod(c$, "setTranslucency",
 function(text, font3d, g3d){
 var pixels = g3d.apiPlatform.getTextPixels(text, font3d, g3d.platform.getGraphicsForTextOrImage(this.mapWidth, this.height), g3d.platform.offscreenImage, this.mapWidth, this.height, this.ascent);
 if (pixels == null) return;
-this.tmap =  Clazz.newByteArray (this.size, 0);
+this.tmap =  Clazz.newByteArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.size, 0);
 for (var i = pixels.length; --i >= 0; ) {
 var p = pixels[i] & 0xFF;
 if (p != 0) {
@@ -137,4 +137,4 @@ c$.working = false;
 c$.htFont3d =  new java.util.Hashtable();
 c$.htFont3dAntialias =  new java.util.Hashtable();
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
