@@ -18,15 +18,15 @@ this.rgb16t1 = null;
 this.rgb16t2 = null;
 Clazz.instantialize(this, arguments);}, J.g3d, "TriangleRenderer", J.g3d.PrecisionRenderer, J.g3d.G3DRenderer);
 Clazz.prepareFields (c$, function(){
-this.ax =  Clazz.newIntArray (3, 0);
-this.ay =  Clazz.newIntArray (3, 0);
-this.az =  Clazz.newIntArray (3, 0);
-this.aa =  Clazz.newFloatArray (64, 0);
-this.bb =  Clazz.newFloatArray (64, 0);
-this.axW =  Clazz.newIntArray (64, 0);
-this.azW =  Clazz.newIntArray (64, 0);
-this.axE =  Clazz.newIntArray (64, 0);
-this.azE =  Clazz.newIntArray (64, 0);
+this.ax =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/3, 0);
+this.ay =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/3, 0);
+this.az =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/3, 0);
+this.aa =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/64, 0);
+this.bb =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/64, 0);
+this.axW =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/64, 0);
+this.azW =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/64, 0);
+this.axE =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/64, 0);
+this.azE =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/64, 0);
 this.rgb16t1 =  new JU.Rgb16();
 this.rgb16t2 =  new JU.Rgb16();
 });
@@ -105,12 +105,12 @@ var nLines = yMax - yMin + 1;
 if (nLines > this.g3d.height * 3) return;
 if (nLines > this.axW.length) {
 var n = (nLines + 31) & -32;
-this.axW =  Clazz.newIntArray (n, 0);
-this.azW =  Clazz.newIntArray (n, 0);
-this.axE =  Clazz.newIntArray (n, 0);
-this.azE =  Clazz.newIntArray (n, 0);
-this.aa =  Clazz.newFloatArray (n, 0);
-this.bb =  Clazz.newFloatArray (n, 0);
+this.axW =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/n, 0);
+this.azW =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/n, 0);
+this.axE =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/n, 0);
+this.azE =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/n, 0);
+this.aa =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/n, 0);
+this.bb =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/n, 0);
 this.rgb16sW = this.reallocRgb16s(this.rgb16sW, n);
 this.rgb16sE = this.reallocRgb16s(this.rgb16sE, n);
 }var gouraudW;
@@ -241,4 +241,4 @@ for (var i = iRaster, iMax = iRaster + dy; i < iMax; ++i) gouraud[i].setAndIncre
 
 }}, "~N,~N,~N,~A,~A,~N,~A");
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
