@@ -43,10 +43,10 @@ this.vertexTest =  new Array(12);
 {
 for (var i = 0; i < 12; i++) this.vertexTest[i] =  new JU.P3();
 
-}this.neighborIndices =  Clazz.newIntArray (16, 0);
+}this.neighborIndices =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/16, 0);
 this.neighborCenters =  new Array(16);
-this.neighborPlusProbeRadii2 =  Clazz.newFloatArray (16, 0);
-this.neighborRadii2 =  Clazz.newFloatArray (16, 0);
+this.neighborPlusProbeRadii2 =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/16, 0);
+this.neighborRadii2 =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/16, 0);
 });
 Clazz.makeConstructor(c$, 
 function(){
@@ -356,4 +356,4 @@ this.ac = this.atomData.ac;
 c$.EMPTY_SET = null;
 c$.power4 =  Clazz.newIntArray(-1, [1, 4, 16, 64, 256]);
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Thu Sep 12 20:50:17 CDT 2024
