@@ -8,4 +8,4 @@ function(vwr, files, width, height, fps, fileName){
 return this.errorMsg;
 }, "JV.Viewer,~A,~N,~N,~N,~S");
 });
-;//5.0.1-v4 Thu Aug 15 08:54:39 CDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
