@@ -49,4 +49,4 @@ import(importPath + "/molfile-to-inchi.js");
 }} catch (t) {
 }
 }});
-;//5.0.1-v4 Thu Aug 15 08:54:39 CDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
