@@ -17,13 +17,13 @@ Clazz.instantialize(this, arguments);}, J.jsv, "JDXMOLParser", null, J.api.JmolJ
 function(loader, filePath, htParams){
 this.loader = loader;
 this.peakFilePath = filePath;
-this.peakIndex =  Clazz.newIntArray (1, 0);
+this.peakIndex =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/1, 0);
 if (htParams != null) {
 htParams.remove("modelNumber");
 if (htParams.containsKey("zipSet")) {
 this.peakIndex = htParams.get("peakIndex");
 if (this.peakIndex == null) {
-this.peakIndex =  Clazz.newIntArray (1, 0);
+this.peakIndex =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/1, 0);
 htParams.put("peakIndex", this.peakIndex);
 }if (!htParams.containsKey("subFileName")) this.peakFilePath = JU.PT.split(filePath, "|")[0];
 }}return this;
@@ -290,4 +290,4 @@ function(s){
 this.line = s;
 }, "~S");
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
