@@ -86,7 +86,7 @@ this.surfaceSet = bsNew;
 this.nSets -= nNull;
 } else if (onlyIfNull) {
 return;
-}this.vertexSets =  Clazz.newIntArray (this.vc, 0);
+}this.vertexSets =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.vc, 0);
 for (var i = 0; i < this.nSets; i++) for (var j = this.surfaceSet[i].nextSetBit(0); j >= 0; j = this.surfaceSet[i].nextSetBit(j + 1)) this.vertexSets[j] = i;
 
 
@@ -133,7 +133,7 @@ function(m, thisSet, isArea, getSets){
 if (getSets || m.nSets <= 0) m.getSurfaceSet();
 var justOne = (thisSet != null && thisSet.cardinality() == 1);
 var n = (justOne || m.nSets <= 0 ? 1 : m.nSets);
-var v =  Clazz.newDoubleArray (n, 0);
+var v =  Clazz.newDoubleArray (/*org.eclipse.jdt.core.dom.SimpleName*/n, 0);
 var vAB =  new JU.V3();
 var vAC =  new JU.V3();
 var vTemp =  new JU.V3();
@@ -159,7 +159,7 @@ for (var i = 0; i < n; i++) v[i] /= factor;
 if (justOne) return Float.$valueOf(v[0]);
 if (thisSet != null) {
 thisSet.and(JU.BSUtil.newBitSet2(0, v.length));
-var v1 =  Clazz.newDoubleArray (thisSet.cardinality(), 0);
+var v1 =  Clazz.newDoubleArray (/*org.eclipse.jdt.core.dom.MethodInvocation*/thisSet.cardinality(), 0);
 for (var pt = 0, i = thisSet.nextSetBit(0); i >= 0; i = thisSet.nextSetBit(i + 1)) {
 v1[pt++] = v[i];
 }
@@ -203,4 +203,4 @@ return (o1.n > o2.n ? -1 : o1.n < o2.n ? 1 : 0);
 /*eoif4*/})();
 };
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
