@@ -34,10 +34,10 @@ this.ptTemp = null;
 Clazz.instantialize(this, arguments);}, J.jvxl.data, "VolumeData", null);
 Clazz.prepareFields (c$, function(){
 this.volumetricOrigin =  new JU.P3();
-this.origin =  Clazz.newFloatArray (3, 0);
+this.origin =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/3, 0);
 this.volumetricVectors =  new Array(3);
-this.voxelCounts =  Clazz.newIntArray (3, 0);
-this.volumetricVectorLengths =  Clazz.newFloatArray (3, 0);
+this.voxelCounts =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/3, 0);
+this.volumetricVectorLengths =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/3, 0);
 this.unitVolumetricVectors =  new Array(3);
 this.volumetricMatrix =  new JU.M3();
 this.inverseMatrix =  new JU.M3();
@@ -296,7 +296,7 @@ this.setPlaneParameters(plane);
 var nx = this.voxelCounts[0];
 var ny = this.voxelCounts[1];
 var nz = this.voxelCounts[2];
-this.voxelData =  Clazz.newFloatArray (nx, ny, nz, 0);
+this.voxelData =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/nx, /*org.eclipse.jdt.core.dom.SimpleName*/ny, /*org.eclipse.jdt.core.dom.SimpleName*/nz, 0);
 for (var x = 0; x < nx; x++) for (var y = 0; y < ny; y++) for (var z = 0; z < nz; z++) this.voxelData[x][y][z] = this.calcVoxelPlaneDistance(x, y, z);
 
 
@@ -381,4 +381,4 @@ v = this.lookupInterpolatedVoxelValue(this.ptTemp, false);
 return v0;
 }, "~N,JU.P3,JU.P3,~N,~N,JU.P3");
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
