@@ -153,12 +153,12 @@ for (var i = 0; i < this.atomData.hAtoms.length; i++) if (this.atomData.hAtoms[i
 nH = hAtoms.length;
 JU.Logger.info(nH + " attached hydrogens added");
 }var n = nH + this.myAtomCount;
-if (getRadii) this.atomRadius =  Clazz.newFloatArray (n, 0);
+if (getRadii) this.atomRadius =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/n, 0);
 this.atomXyzTruncated =  new Array(n);
-if (this.params.theProperty != null) this.atomProp =  Clazz.newFloatArray (n, 0);
-this.atomNo =  Clazz.newIntArray (n, 0);
-this.atomIndex =  Clazz.newIntArray (n, 0);
-this.myIndex =  Clazz.newIntArray (this.ac, 0);
+if (this.params.theProperty != null) this.atomProp =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/n, 0);
+this.atomNo =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/n, 0);
+this.atomIndex =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/n, 0);
+this.myIndex =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.ac, 0);
 for (var i = 0; i < nH; i++) {
 if (getRadii) this.atomRadius[i] = rH;
 this.atomXyzTruncated[i] = hAtoms[i];
@@ -223,8 +223,8 @@ Clazz.defineMethod(c$, "setRadii",
 function(){
 if (this.rs != null) return;
 this.maxRS = 0;
-this.rs =  Clazz.newFloatArray (this.myAtomCount, 0);
-this.rs2 =  Clazz.newFloatArray (this.myAtomCount, 0);
+this.rs =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.myAtomCount, 0);
+this.rs2 =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.myAtomCount, 0);
 for (var i = 0; i < this.myAtomCount; i++) {
 var r = this.rs[i] = this.atomRadius[i] + this.sr;
 if (r > this.maxRS) this.maxRS = r;
@@ -375,4 +375,4 @@ if (this.isProgressive) this.thisPlane[ipt % this.yzCount] = value;
  else this.voxelData[i][j][k] = value;
 }, "~N,~N,~N,~N,~N");
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
