@@ -131,7 +131,7 @@ var sampleCounts = this.readCifP3("_volume_data_3d_info_sample_count", this.p3);
 this.mapc = Clazz.floatToInt(axis_order.x) + 1;
 this.mapr = Clazz.floatToInt(axis_order.y) + 1;
 this.maps = Clazz.floatToInt(axis_order.z) + 1;
-var crs2abc =  Clazz.newIntArray (3, 0);
+var crs2abc =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/3, 0);
 crs2abc[this.mapc - 1] = 0;
 crs2abc[this.mapr - 1] = 1;
 crs2abc[this.maps - 1] = 2;
@@ -158,7 +158,7 @@ this.readCifP3("_volume_data_3d_info_spacegroup_cell_angles", this.p3);
 this.alpha = this.p3.x;
 this.beta = this.p3.y;
 this.gamma = this.p3.z;
-this.values = this.readCifFloats("_volume_data_3d_values",  Clazz.newFloatArray (this.na * this.nb * this.nc, 0));
+this.values = this.readCifFloats("_volume_data_3d_values",  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.InfixExpression*/this.na * this.nb * this.nc, 0));
 this.getVectorsAndOrigin();
 if (this.params.thePlane == null && (this.params.cutoffAutomatic || !Float.isNaN(this.params.sigma))) {
 var sigma = (this.params.sigma < 0 || Float.isNaN(this.params.sigma) ? 1 : this.params.sigma);
@@ -198,4 +198,4 @@ System.out.println("CifDensityReader checkSum=" + this.checkSum);
 Clazz.superCall(this, J.jvxl.readers.BCifDensityReader, "closeReader", []);
 });
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
