@@ -52,7 +52,7 @@ this.jvxlFileHeaderBuffer.append("DelPhi DATA ").append(nxttoplbl.$replace('\n',
 Clazz.defineMethod(c$, "readString", 
 function(){
 var n = this.binarydoc.readInt();
-var buf =  Clazz.newByteArray (n, 0);
+var buf =  Clazz.newByteArray (/*org.eclipse.jdt.core.dom.SimpleName*/n, 0);
 this.binarydoc.readByteArray(buf, 0, n);
 this.binarydoc.readInt();
 return  String.instantialize(buf);
@@ -60,7 +60,7 @@ return  String.instantialize(buf);
 Clazz.defineMethod(c$, "readFloatArray", 
 function(){
 var n = this.binarydoc.readInt() >> 2;
-var a =  Clazz.newFloatArray (n, 0);
+var a =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/n, 0);
 for (var i = 0; i < n; i++) a[i] = this.binarydoc.readFloat();
 
 this.binarydoc.readInt();
@@ -76,4 +76,4 @@ function(nPoints){
 this.pt += nPoints;
 }, "~N");
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
