@@ -29,7 +29,7 @@ this.nSurfaces = 1;
 }, "J.jvxl.readers.SurfaceGenerator,java.io.BufferedReader");
 Clazz.overrideMethod(c$, "readParameters", 
 function(){
-var header =  Clazz.newShortArray (19, 0);
+var header =  Clazz.newShortArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/19, 0);
 for (var i = 0; i < 19; i++) header[i] = this.binarydoc.readShort();
 
 if (header[18] != 100) {
@@ -84,7 +84,7 @@ this.nBrickX = Clazz.doubleToInt((this.n0 + 7) / 8);
 this.nBrickY = Clazz.doubleToInt((this.n1 + 7) / 8);
 this.brickRowByteCount = this.nBrickX * 512;
 this.brickLayerByteCount = this.brickRowByteCount * this.nBrickY;
-this.brickLayer =  Clazz.newByteArray (this.brickLayerByteCount, 0);
+this.brickLayer =  Clazz.newByteArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.brickLayerByteCount, 0);
 this.jvxlFileHeaderBuffer =  new JU.SB();
 this.jvxlFileHeaderBuffer.append("DNS6/O progressive brick data reader\n");
 this.jvxlFileHeaderBuffer.append("see http://www.uoxray.uoregon.edu/tnt/manual/node104.html\n");
@@ -122,4 +122,4 @@ for (var i = 0; i < nPoints; i++) this.binarydoc.readByte();
 
 }, "~N");
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
