@@ -34,12 +34,12 @@ var pt =  new JU.P3();
 var value = 0;
 this.skipTo("<vertices", "count");
 this.jvxlData.vertexCount = this.nVertices = this.parseInt();
-this.vertexMap =  Clazz.newIntArray (this.nVertices + 1, 0);
+this.vertexMap =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.InfixExpression*/this.nVertices + 1, 0);
 this.jvxlData.vertexColors = null;
 if (this.params.fileIndex == 0) {
-this.jvxlData.vertexColors =  Clazz.newIntArray (this.nVertices, 0);
+this.jvxlData.vertexColors =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.nVertices, 0);
 this.jvxlData.nVertexColors = 0;
-}var values =  Clazz.newFloatArray (this.jvxlData.vertexColors == null ? 3 : 9, 0);
+}var values =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.ConditionalExpression*/this.jvxlData.vertexColors == null ? 3 : 9, 0);
 this.skipTo("property=", null);
 this.line = this.line.$replace('"', ' ');
 var tokens = this.getTokens();
@@ -77,4 +77,4 @@ function(){
 return this.vertexMap[this.parseInt()];
 });
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
