@@ -7,7 +7,7 @@ this.func = null;
 this.values = null;
 Clazz.instantialize(this, arguments);}, J.jvxl.readers, "IsoFxyReader", J.jvxl.readers.AtomDataReader);
 Clazz.prepareFields (c$, function(){
-this.values =  Clazz.newFloatArray (3, 0);
+this.values =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/3, 0);
 });
 Clazz.makeConstructor(c$, 
 function(){
@@ -96,4 +96,4 @@ this.volumeData.voxelPtToXYZ(x, y, z, this.ptTemp);
 return this.getValueAtPoint(this.ptTemp, false);
 }, "~N,~N,~N");
 });
-;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
+;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
